/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2013  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.88e                                            *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : LED.c          (for MSC ModSDKM16C-CM16C62P development kit)
Purpose : LED interface
--------  END-OF-HEADER  ---------------------------------------------
*/

#define  LED_C
#include "LED.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

/****** SFRs used for LED-Port **************************************/
/*      We define sfrs used here to keep the code generic without   */
/*      the need to include an sfr definition header file           */
 
#define _P7  (*(volatile unsigned char*)0x3C1)   /* Port P7 register */
#define _P7D (*(volatile unsigned char*)0x3C3)   /* Port P7 direction register */

#define _LED_PORT     (_P7)
#define _LED_PORT_DIR (_P7D)

/****** Assign LEDs to Ports ****************************************/

#define _LED0_BIT  (3)
#define _LED1_BIT  (6)
#define _LED0_MASK (1 << _LED0_BIT)
#define _LED1_MASK (1 << _LED1_BIT)
#define _LED_MASK_ALL (_LED0_MASK | _LED1_MASK)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       LED_Init()
*/
void LED_Init(void) {
  //
  // Initially switch off LEDs
  //
  _LED_PORT = 0;
  //
  // Enable output port for LEDS
  //
  _LED_PORT_DIR = 0;
  _LED_PORT_DIR |= _LED_MASK_ALL;
}

/*********************************************************************
*
*       LED switching routines
*/
void LED_SetLED0(void) {
  _LED_PORT |= _LED0_MASK;
}

void LED_ClrLED0(void) {
  _LED_PORT &= ~_LED0_MASK;
}

void LED_ToggleLED0(void) {
  _LED_PORT ^= _LED0_MASK;
}

void LED_SetLED1(void) {
  _LED_PORT |= _LED1_MASK;
}

void LED_ClrLED1(void) {
  _LED_PORT &= ~_LED1_MASK;
}

void LED_ToggleLED1(void) {
  _LED_PORT ^= _LED1_MASK;
}

/****** End Of File *************************************************/

