/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2013  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.88e                                            *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : CPUM32C.h
Purpose : SFR defines for M32C/83 CPU in ANSI C
---------------------------END-OF-HEADER------------------------------
*/

/****  data format definition  ***********************/   

#ifndef U8
  #define U8 unsigned char
#endif

#ifndef U16
  #define U16 unsigned short
#endif

#ifndef U32
  #define U32 unsigned long
#endif


#define fct_loc_1

/****  Processor Registers  ***************************/

#define PM0      (*(volatile U8* ) 0x000004)  // Processor Mode Register 0
#define PM1      (*(volatile U8* ) 0x000005)  // Processor Mode Register 1
#define CM0      (*(volatile U8* ) 0x000006)  // System clock control register 0
#define CM1      (*(volatile U8* ) 0x000007)  // System clock control register 1
#define WCR      (*(volatile U8* ) 0x000008)  // Wait control register
#define PRCR     (*(volatile U8* ) 0x00000A)  // Protect register
#define DS       (*(volatile U8* ) 0x00000B)  // External data bus width control register
#define MCD      (*(volatile U8* ) 0x00000C)  // Main clock division register
#define DRAMCONT (*(volatile U8* ) 0x000040)  // DRAM control register
#define REFCNT   (*(volatile U8* ) 0x000041)  // DRAM refresh interval set register
#define CM2      (*(volatile U8* ) 0x00000D)  // Oscillation stop detect register
#define PLV      (*(volatile U8* ) 0x000017)  // VDC control register for PLL
#define PLC0     (*(volatile U8* ) 0x000376)  // PLL control register 0
#define IPS      (*(volatile U8* ) 0x000178)  // Input function select register

/************************  Emulation Control Registers  *******************/
/***************  THESE REGISTERS ARE NOT AVAILABLE FOR USERS *************/
#define VDC1     (*(volatile U8* ) 0x00001B)  // VDC control register 1
#define VDC0     (*(volatile U8* ) 0x00001F)  // VDC control register 0
#define EIAD0    (*(volatile U32*) 0x000020)  // Emulator interrupt vector table register
#define EIAD00   (*(volatile U8* ) 0x000020)  // Emulator interrupt vector table register (low)
#define EIAD01   (*(volatile U8* ) 0x000021)  // Emulator interrupt vector table register (mid)
#define EIAD02   (*(volatile U8* ) 0x000022)  // Emulator interrupt vector table register (high)
#define EITD     (*(volatile U8* ) 0x000023)  // Emulator interrupt detect register
#define EPRR     (*(volatile U8* ) 0x000024)  // Emulator protect register
#define ROA      (*(volatile U8* ) 0x000030)  // ROM area set register
#define DBA      (*(volatile U8* ) 0x000031)  // Debug monitor area set register
#define EXA0     (*(volatile U8* ) 0x000032)  // Expansion area set register 0
#define EXA1     (*(volatile U8* ) 0x000033)  // Expansion area set register 1
#define EXA2     (*(volatile U8* ) 0x000034)  // Expansion area set register 2
#define EXA3     (*(volatile U8* ) 0x000035)  // Expansion area set register 3
#define FMR2     (*(volatile U8* ) 0x000055)  // Flash memory control register 2
#define FMR1     (*(volatile U8* ) 0x000056)  // Flash memory control register 1

/************************  Watchdog Timer  ********************************/
#define WDTS     (*(volatile U8* ) 0x00000E)  // Watchdog timer start register
#define WDC      (*(volatile U8* ) 0x00000F)  // Watchdog timer control register

/************************  Flash memory control register  *****************/
#define FMR0     (*(volatile U8* ) 0x000057)  // Flash memory control register 0

/************************  Interrupt Control Register  ********************/
#define AIER     (*(volatile U8* ) 0x000009)  // Address match interrupt control register
#define RMAD0    (*(volatile U32*) 0x000010)  // Address match interrupt register 0
#define RMAD00   (*(volatile U8* ) 0x000010)  // Address match interrupt register 0 (low)
#define RMAD01   (*(volatile U8* ) 0x000011)  // Address match interrupt register 0 (mid)
#define RMAD02   (*(volatile U8* ) 0x000012)  // Address match interrupt register 0 (high)
#define RMAD1    (*(volatile U32*) 0x000014)  // Address match interrupt register 1
#define RMAD10   (*(volatile U8* ) 0x000014)  // Address match interrupt register 1 (low)
#define RMAD11   (*(volatile U8* ) 0x000015)  // Address match interrupt register 1 (mid)
#define RMAD12   (*(volatile U8* ) 0x000016)  // Address match interrupt register 1 (high)
#define RMAD2    (*(volatile U32*) 0x000018)  // Address match interrupt register 2
#define RMAD20   (*(volatile U8* ) 0x000018)  // Address match interrupt register 2 (low)
#define RMAD21   (*(volatile U8* ) 0x000019)  // Address match interrupt register 2 (mid)
#define RMAD22   (*(volatile U8* ) 0x00001A)  // Address match interrupt register 2 (high)
#define RMAD3    (*(volatile U32*) 0x00001C)  // Address match interrupt register 3
#define RMAD30   (*(volatile U8* ) 0x00001C)  // Address match interrupt register 3 (low)
#define RMAD31   (*(volatile U8* ) 0x00001D)  // Address match interrupt register 3 (mid)
#define RMAD32   (*(volatile U8* ) 0x00001E)  // Address match interrupt register 3 (high)
#define DM0IC    (*(volatile U8* ) 0x000068)  // DMA0 interrupt control register
#define DM1IC    (*(volatile U8* ) 0x000088)  // DMA1 interrupt control register
#define DM2IC    (*(volatile U8* ) 0x00006A)  // DMA2 interrupt control register
#define DM3IC    (*(volatile U8* ) 0x00008A)  // DMA3 interrupt control register
#define KURIC    (*(volatile U8* ) 0x000093)  // Key input interrupt control register
#define AD0IC    (*(volatile U8* ) 0x000073)  // A-D0 interrupt control register
#define AD1IC    (*(volatile U8* ) 0x000086)  // A-D1 interrupt control register
#define S0TIC    (*(volatile U8* ) 0x000090)  // UART0 transmit/NACK interrupt control register
#define S0RIC    (*(volatile U8* ) 0x000072)  // UART0 receive/ACK interrupt control register
#define BCN0IC   (*(volatile U8* ) 0x000071)  // UART0/UART3 but collision detection interrupt control register
#define S1TIC    (*(volatile U8* ) 0x000092)  // UART1 transmit/NACK interrupt control register
#define S1RIC    (*(volatile U8* ) 0x000074)  // UART1 receive/ACK interrupt control register
#define BCN1IC   (*(volatile U8* ) 0x000091)  // UART1/UART4 but collision detection interrupt control register
#define S2TIC    (*(volatile U8* ) 0x000089)  // UART2 transmit/NACK interrupt control register
#define S2RIC    (*(volatile U8* ) 0x00006B)  // UART2 receive/ACK interrupt control register
#define BCN2IC   (*(volatile U8* ) 0x00008F)  // UART2 bus collision detection interrupt control register
#define S3TIC    (*(volatile U8* ) 0x00008B)  // UART3 transmit/NACK interrupt control register
#define S3RIC    (*(volatile U8* ) 0x00006D)  // UART3 receive/ACK interrupt control register
#define S4TIC    (*(volatile U8* ) 0x00008D)  // UART4 transmit/NACK interrupt control register
#define S4RIC    (*(volatile U8* ) 0x00006F)  // UART4 receive/ACK interrupt control register
#define TA0IC    (*(volatile U8* ) 0x00006C)  // Timer A0 interrupt control register
#define TA1IC    (*(volatile U8* ) 0x00008C)  // Timer A1 interrupt control register
#define TA2IC    (*(volatile U8* ) 0x00006E)  // Timer A2 interrupt control register
#define TA3IC    (*(volatile U8* ) 0x00008E)  // Timer A3 interrupt control register
#define TA4IC    (*(volatile U8* ) 0x000070)  // Timer A4 interrupt control register
#define TB0IC    (*(volatile U8* ) 0x000094)  // Timer B0 interrupt control register
#define TB1IC    (*(volatile U8* ) 0x000076)  // Timer B1 interrupt control register
#define TB2IC    (*(volatile U8* ) 0x000096)  // Timer B2 interrupt control register
#define TB3IC    (*(volatile U8* ) 0x000078)  // Timer B3 interrupt control register
#define TB4IC    (*(volatile U8* ) 0x000098)  // Timer B4 interrupt control register
#define TB5IC    (*(volatile U8* ) 0x000069)  // Timer B5 interrupt control register
#define INT0IC   (*(volatile U8* ) 0x00009E)  // Interrupt 0 interrupt control register
#define INT1IC   (*(volatile U8* ) 0x00007E)  // Interrupt 1 interrupt control register
#define INT2IC   (*(volatile U8* ) 0x00009C)  // Interrupt 2 interrupt control register
#define INT3IC   (*(volatile U8* ) 0x00007C)  // Interrupt 3 interrupt control register
#define INT4IC   (*(volatile U8* ) 0x00009A)  // Interrupt 4 interrupt control register
#define INT5IC   (*(volatile U8* ) 0x00007A)  // Interrupt 5 interrupt control register
#define IIO0IC   (*(volatile U8* ) 0x000075)  // Intelligent I/O interrupt control register 0
#define IIO1IC   (*(volatile U8* ) 0x000095)  // Intelligent I/O interrupt control register 1
#define IIO2IC   (*(volatile U8* ) 0x000077)  // Intelligent I/O interrupt control register 2
#define IIO3IC   (*(volatile U8* ) 0x000097)  // Intelligent I/O interrupt control register 3
#define IIO4IC   (*(volatile U8* ) 0x000079)  // Intelligent I/O interrupt control register 4
#define IIO5IC   (*(volatile U8* ) 0x000099)  // Intelligent I/O interrupt control register 5
#define IIO6IC   (*(volatile U8* ) 0x00007B)  // Intelligent I/O interrupt control register 6
#define IIO7IC   (*(volatile U8* ) 0x00009B)  // Intelligent I/O interrupt control register 7
#define IIO8IC   (*(volatile U8* ) 0x00007D)  // Intelligent I/O interrupt control register 8
#define IIO9IC   (*(volatile U8* ) 0x00009D)  // Intelligent I/O interrupt control register 9
#define IIO10IC  (*(volatile U8* ) 0x00007F)  // Intelligent I/O interrupt control register 10
#define IIO11IC  (*(volatile U8* ) 0x000081)  // Intelligent I/O interrupt control register 11
#define IIO0IR   (*(volatile U8* ) 0x0000A0)  // Interrupt request register 0
#define IIO1IR   (*(volatile U8* ) 0x0000A1)  // Interrupt request register 1
#define IIO2IR   (*(volatile U8* ) 0x0000A2)  // Interrupt request register 2
#define IIO3IR   (*(volatile U8* ) 0x0000A3)  // Interrupt request register 3
#define IIO4IR   (*(volatile U8* ) 0x0000A4)  // Interrupt request register 4
#define IIO5IR   (*(volatile U8* ) 0x0000A5)  // Interrupt request register 5
#define IIO6IR   (*(volatile U8* ) 0x0000A6)  // Interrupt request register 6
#define IIO7IR   (*(volatile U8* ) 0x0000A7)  // Interrupt request register 7
#define IIO8IR   (*(volatile U8* ) 0x0000A8)  // Interrupt request register 8
#define IIO9IR   (*(volatile U8* ) 0x0000A9)  // Interrupt request register 9
#define IIO10IR  (*(volatile U8* ) 0x0000AA)  // Interrupt request register 10
#define IIO11IR  (*(volatile U8* ) 0x0000AB)  // Interrupt request register 11
#define IIO0IE   (*(volatile U8* ) 0x0000B0)  // Interrupt enable register 0
#define IIO1IE   (*(volatile U8* ) 0x0000B1)  // Interrupt enable register 1
#define IIO2IE   (*(volatile U8* ) 0x0000B2)  // Interrupt enable register 2
#define IIO3IE   (*(volatile U8* ) 0x0000B3)  // Interrupt enable register 3
#define IIO4IE   (*(volatile U8* ) 0x0000B4)  // Interrupt enable register 4
#define IIO5IE   (*(volatile U8* ) 0x0000B5)  // Interrupt enable register 5
#define IIO6IE   (*(volatile U8* ) 0x0000B6)  // Interrupt enable register 6
#define IIO7IE   (*(volatile U8* ) 0x0000B7)  // Interrupt enable register 7
#define IIO8IE   (*(volatile U8* ) 0x0000B8)  // Interrupt enable register 8
#define IIO9IE   (*(volatile U8* ) 0x0000B9)  // Interrupt enable register 9
#define IIO10IE  (*(volatile U8* ) 0x0000BA)  // Interrupt enable register 10
#define IIO11IE  (*(volatile U8* ) 0x0000BB)  // Interrupt enable register 11
#define RLVL     (*(volatile U8* ) 0x00009F)  // EXIT priority control register
#define IFSR     (*(volatile U8* ) 0x00031F)  // External interrupt cause select register

/************************  Group 0 Register  ******************************/
#define G0TM0    (*(volatile U16*) 0x0000C0)  // Group 0 TM register 0
#define G0PO0    (*(volatile U16*) 0x0000C0)  // Group 0 WG register 0
#define G0TM1    (*(volatile U16*) 0x0000C2)  // Group 0 TM register 1
#define G0PO1    (*(volatile U16*) 0x0000C2)  // Group 0 WG register 1
#define G0TM2    (*(volatile U16*) 0x0000C4)  // Group 0 TM register 2
#define G0PO2    (*(volatile U16*) 0x0000C4)  // Group 0 WG register 2
#define G0TM3    (*(volatile U16*) 0x0000C6)  // Group 0 TM register 3
#define G0PO3    (*(volatile U16*) 0x0000C6)  // Group 0 WG register 3
#define G0TM4    (*(volatile U16*) 0x0000C8)  // Group 0 TM register 4
#define G0PO4    (*(volatile U16*) 0x0000C8)  // Group 0 WG register 4
#define G0TM5    (*(volatile U16*) 0x0000CA)  // Group 0 TM register 5
#define G0PO5    (*(volatile U16*) 0x0000CA)  // Group 0 WG register 5
#define G0TM6    (*(volatile U16*) 0x0000CC)  // Group 0 TM register 6
#define G0PO6    (*(volatile U16*) 0x0000CC)  // Group 0 WG register 6
#define G0TM7    (*(volatile U16*) 0x0000CE)  // Group 0 TM register 7
#define G0PO7    (*(volatile U16*) 0x0000CE)  // Group 0 WG register 7
#define G0POCR0  (*(volatile U8* ) 0x0000D0)  // Group 0 waveform generate control register 0
#define G0POCR1  (*(volatile U8* ) 0x0000D1)  // Group 0 waveform generate control register 1
#define G0POCR2  (*(volatile U8* ) 0x0000D2)  // Group 0 waveform generate control register 2
#define G0POCR3  (*(volatile U8* ) 0x0000D3)  // Group 0 waveform generate control register 3
#define G0POCR4  (*(volatile U8* ) 0x0000D4)  // Group 0 waveform generate control register 4
#define G0POCR5  (*(volatile U8* ) 0x0000D5)  // Group 0 waveform generate control register 5
#define G0POCR6  (*(volatile U8* ) 0x0000D6)  // Group 0 waveform generate control register 6
#define G0POCR7  (*(volatile U8* ) 0x0000D7)  // Group 0 waveform generate control register 7
#define G0TMCR0  (*(volatile U8* ) 0x0000D8)  // Group 0 time measurement control register 0
#define G0TMCR1  (*(volatile U8* ) 0x0000D9)  // Group 0 time measurement control register 1
#define G0TMCR2  (*(volatile U8* ) 0x0000DA)  // Group 0 time measurement control register 2
#define G0TMCR3  (*(volatile U8* ) 0x0000DB)  // Group 0 time measurement control register 3
#define G0TMCR4  (*(volatile U8* ) 0x0000DC)  // Group 0 time measurement control register 4
#define G0TMCR5  (*(volatile U8* ) 0x0000DD)  // Group 0 time measurement control register 5
#define G0TMCR6  (*(volatile U8* ) 0x0000DE)  // Group 0 time measurement control register 6
#define G0TMCR7  (*(volatile U8* ) 0x0000DF)  // Group 0 time measurement control register 7
#define G0BT     (*(volatile U16*) 0x0000E0)  // Group 0 base timer register
#define G0BCR0   (*(volatile U8* ) 0x0000E2)  // Group 0 base timer control register 0
#define G0BCR1   (*(volatile U8* ) 0x0000E3)  // Group 0 base timer control register 1
#define G0TPR6   (*(volatile U8* ) 0x0000E4)  // Group 0 time measurement prescaler register 6
#define G0TPR7   (*(volatile U8* ) 0x0000E5)  // Group 0 time measurement prescaler register 7
#define G0FE     (*(volatile U8* ) 0x0000E6)  // Group 0 function enable register
#define G0FS     (*(volatile U8* ) 0x0000E7)  // Group 0 function select register
#define G0BF     (*(volatile U16*) 0x0000E8)  // Group 0 SI/O receive buffer register
#define G0DR     (*(volatile U8* ) 0x0000EA)  // Group 0 transmit buffer/receive data register
#define G0RI     (*(volatile U8* ) 0x0000EC)  // Group 0 receive input register
#define G0MR     (*(volatile U8* ) 0x0000ED)  // Group 0 communication mode register
#define G0TO     (*(volatile U8* ) 0x0000EE)  // Group 0 transmit output register
#define G0CR     (*(volatile U8* ) 0x0000EF)  // Group 0 SI/O communication control register
#define G0CMP0   (*(volatile U8* ) 0x0000F0)  // Group 0 data compare register 0
#define G0CMP1   (*(volatile U8* ) 0x0000F1)  // Group 0 data compare register 1
#define G0CMP2   (*(volatile U8* ) 0x0000F2)  // Group 0 data compare register 2
#define G0CMP3   (*(volatile U8* ) 0x0000F3)  // Group 0 data compare register 3
#define G0MSK0   (*(volatile U8* ) 0x0000F4)  // Group 0 data mask register 0
#define G0MSK1   (*(volatile U8* ) 0x0000F5)  // Group 0 data mask register 1
#define G0RCRC   (*(volatile U16*) 0x0000F8)  // Group 0 receive CRC code register
#define G0TCRC   (*(volatile U16*) 0x0000FA)  // Group 0 transmit CRC code register
#define G0EMR    (*(volatile U8* ) 0x0000FC)  // Group 0 SI/O expansion mode register
#define G0ERC    (*(volatile U8* ) 0x0000FD)  // Group 0 SI/O expansion receive control register
#define G0IRF    (*(volatile U8* ) 0x0000FE)  // Group 0 SI/O special communication interrupt detect register
#define G0ETC    (*(volatile U8* ) 0x0000FF)  // Group 0 SI/O expansion transmit control register

/************************  Group 1 Register  ******************************/
#define G1TM0    (*(volatile U16*) 0x000100)  // Group 1 TM register 0
#define G1PO0    (*(volatile U16*) 0x000100)  // Group 1 WG register 0
#define G1TM1    (*(volatile U16*) 0x000102)  // Group 1 TM register 1
#define G1PO1    (*(volatile U16*) 0x000102)  // Group 1 WG register 1
#define G1TM2    (*(volatile U16*) 0x000104)  // Group 1 TM register 2
#define G1PO2    (*(volatile U16*) 0x000104)  // Group 1 WG register 2
#define G1TM3    (*(volatile U16*) 0x000106)  // Group 1 TM register 3
#define G1PO3    (*(volatile U16*) 0x000106)  // Group 1 WG register 3
#define G1TM4    (*(volatile U16*) 0x000108)  // Group 1 TM register 4
#define G1PO4    (*(volatile U16*) 0x000108)  // Group 1 WG register 4
#define G1TM5    (*(volatile U16*) 0x00010A)  // Group 1 TM register 5
#define G1PO5    (*(volatile U16*) 0x00010A)  // Group 1 WG register 5
#define G1TM6    (*(volatile U16*) 0x00010C)  // Group 1 TM register 6
#define G1PO6    (*(volatile U16*) 0x00010C)  // Group 1 WG register 6
#define G1TM7    (*(volatile U16*) 0x00010E)  // Group 1 TM register 7
#define G1PO7    (*(volatile U16*) 0x00010E)  // Group 1 WG register 7
#define G1POCR0  (*(volatile U8* ) 0x000110)  // Group 1 waveform generate control register 0
#define G1POCR1  (*(volatile U8* ) 0x000111)  // Group 1 waveform generate control register 1
#define G1POCR2  (*(volatile U8* ) 0x000112)  // Group 1 waveform generate control register 2
#define G1POCR3  (*(volatile U8* ) 0x000113)  // Group 1 waveform generate control register 3
#define G1POCR4  (*(volatile U8* ) 0x000114)  // Group 1 waveform generate control register 4
#define G1POCR5  (*(volatile U8* ) 0x000115)  // Group 1 waveform generate control register 5
#define G1POCR6  (*(volatile U8* ) 0x000116)  // Group 1 waveform generate control register 6
#define G1POCR7  (*(volatile U8* ) 0x000117)  // Group 1 waveform generate control register 7
#define G1TMCR0  (*(volatile U8* ) 0x000118)  // Group 1 time measurement control register 0
#define G1TMCR1  (*(volatile U8* ) 0x000119)  // Group 1 time measurement control register 1
#define G1TMCR2  (*(volatile U8* ) 0x00011A)  // Group 1 time measurement control register 2
#define G1TMCR3  (*(volatile U8* ) 0x00011B)  // Group 1 time measurement control register 3
#define G1TMCR4  (*(volatile U8* ) 0x00011C)  // Group 1 time measurement control register 4
#define G1TMCR5  (*(volatile U8* ) 0x00011D)  // Group 1 time measurement control register 5
#define G1TMCR6  (*(volatile U8* ) 0x00011E)  // Group 1 time measurement control register 6
#define G1TMCR7  (*(volatile U8* ) 0x00011F)  // Group 1 time measurement control register 7
#define G1BT     (*(volatile U16*) 0x000120)  // Group 1 base timer register
#define G1BCR0   (*(volatile U8* ) 0x000122)  // Group 1 base timer control register 0
#define G1BCR1   (*(volatile U8* ) 0x000123)  // Group 1 base timer control register 1
#define G1TPR6   (*(volatile U8* ) 0x000124)  // Group 1 time measurement prescaler register 6
#define G1TPR7   (*(volatile U8* ) 0x000125)  // Group 1 time measurement prescaler register 7
#define G1FE     (*(volatile U8* ) 0x000126)  // Group 1 function enable register
#define G1FS     (*(volatile U8* ) 0x000127)  // Group 1 function select register
#define G1BF     (*(volatile U16*) 0x000128)  // Group 1 SI/O receive buffer register
#define G1DR     (*(volatile U8* ) 0x00012A)  // Group 1 transmit buffer/receive data register
#define G1RI     (*(volatile U8* ) 0x00012C)  // Group 1 receive input register
#define G1MR     (*(volatile U8* ) 0x00012D)  // Group 1 communication mode register
#define G1TO     (*(volatile U8* ) 0x00012E)  // Group 1 transmit output register
#define G1CR     (*(volatile U8* ) 0x00012F)  // Group 1 SI/O communication control register
#define G1CMP0   (*(volatile U8* ) 0x000130)  // Group 1 data compare register 0
#define G1CMP1   (*(volatile U8* ) 0x000131)  // Group 1 data compare register 1
#define G1CMP2   (*(volatile U8* ) 0x000132)  // Group 1 data compare register 2
#define G1CMP3   (*(volatile U8* ) 0x000133)  // Group 1 data compare register 3
#define G1MSK0   (*(volatile U8* ) 0x000134)  // Group 1 data mask register 0
#define G1MSK1   (*(volatile U8* ) 0x000135)  // Group 1 data mask register 1
#define G1RCRC   (*(volatile U16*) 0x000138)  // Group 1 receive CRC code register
#define G1TCRC   (*(volatile U16*) 0x00013A)  // Group 1 transmit CRC code register
#define G1EMR    (*(volatile U8* ) 0x00013C)  // Group 1 SI/O expansion mode register
#define G1ERC    (*(volatile U8* ) 0x00013D)  // Group 1 SI/O expansion receive control register
#define G1IRF    (*(volatile U8* ) 0x00013E)  // Group 1 SI/O special communication interrupt detect register
#define G1ETC    (*(volatile U8* ) 0x00013F)  // Group 1 SI/O expansion transmit control register

/************************  Group 2 Register  ******************************/
#define G2PO0    (*(volatile U16*) 0x000140)  // Group 2 WG register 0
#define G2PO1    (*(volatile U16*) 0x000142)  // Group 2 WG register 1
#define G2PO2    (*(volatile U16*) 0x000144)  // Group 2 WG register 2
#define G2PO3    (*(volatile U16*) 0x000146)  // Group 2 WG register 3
#define G2PO4    (*(volatile U16*) 0x000148)  // Group 2 WG register 4
#define G2PO5    (*(volatile U16*) 0x00014A)  // Group 2 WG register 5
#define G2PO6    (*(volatile U16*) 0x00014C)  // Group 2 WG register 6
#define G2PO7    (*(volatile U16*) 0x00014E)  // Group 2 WG register 7
#define G2POCR0  (*(volatile U8* ) 0x000150)  // Group 2 waveform generate control register 0
#define G2POCR1  (*(volatile U8* ) 0x000151)  // Group 2 waveform generate control register 1
#define G2POCR2  (*(volatile U8* ) 0x000152)  // Group 2 waveform generate control register 2
#define G2POCR3  (*(volatile U8* ) 0x000153)  // Group 2 waveform generate control register 3
#define G2POCR4  (*(volatile U8* ) 0x000154)  // Group 2 waveform generate control register 4
#define G2POCR5  (*(volatile U8* ) 0x000155)  // Group 2 waveform generate control register 5
#define G2POCR6  (*(volatile U8* ) 0x000156)  // Group 2 waveform generate control register 6
#define G2POCR7  (*(volatile U8* ) 0x000157)  // Group 2 waveform generate control register 7
#define G2BT     (*(volatile U16*) 0x000160)  // Group 2 base timer register
#define G2BCR0   (*(volatile U8* ) 0x000162)  // Group 2 base timer control register 0
#define G2BCR1   (*(volatile U8* ) 0x000163)  // Group 2 base timer control register 1
#define G2FE     (*(volatile U8* ) 0x000166)  // Group 2 function enable register
#define G2RTP    (*(volatile U8* ) 0x000167)  // Group 2 RTP output buffer register
#define G2MR     (*(volatile U8* ) 0x00016A)  // Group 2 SI/O communication mode register
#define G2CR     (*(volatile U8* ) 0x00016B)  // Group 2 SI/O communication control register
#define G2TB     (*(volatile U16*) 0x00016C)  // Group 2 SI/O transmit buffer register
#define G2RB     (*(volatile U16*) 0x00016E)  // Group 2 SI/O receive buffer register
#define IEAR     (*(volatile U16*) 0x000170)  // Group 2 IEBus address register
#define IECR     (*(volatile U8* ) 0x000172)  // Group 2 IEBus control register
#define IETIF    (*(volatile U8* ) 0x000173)  // Group 2 IEBus transmit interrupt cause detect register
#define IERIF    (*(volatile U8* ) 0x000174)  // Group 2 IEBus receive interrupt cause detect register

/************************  Group 3 Register  ******************************/
#define G3PO0    (*(volatile U16*) 0x000180)  // Group 3 WG register 0
#define G3PO1    (*(volatile U16*) 0x000182)  // Group 3 WG register 1
#define G3PO2    (*(volatile U16*) 0x000184)  // Group 3 WG register 2
#define G3PO3    (*(volatile U16*) 0x000186)  // Group 3 WG register 3
#define G3PO4    (*(volatile U16*) 0x000188)  // Group 3 WG register 4
#define G3PO5    (*(volatile U16*) 0x00018A)  // Group 3 WG register 5
#define G3PO6    (*(volatile U16*) 0x00018C)  // Group 3 WG register 6
#define G3PO7    (*(volatile U16*) 0x00018E)  // Group 3 WG register 7
#define G3POCR0  (*(volatile U8* ) 0x000190)  // Group 3 waveform generate control register 0
#define G3POCR1  (*(volatile U8* ) 0x000191)  // Group 3 waveform generate control register 1
#define G3POCR2  (*(volatile U8* ) 0x000192)  // Group 3 waveform generate control register 2
#define G3POCR3  (*(volatile U8* ) 0x000193)  // Group 3 waveform generate control register 3
#define G3POCR4  (*(volatile U8* ) 0x000194)  // Group 3 waveform generate control register 4
#define G3POCR5  (*(volatile U8* ) 0x000195)  // Group 3 waveform generate control register 5
#define G3POCR6  (*(volatile U8* ) 0x000196)  // Group 3 waveform generate control register 6
#define G3POCR7  (*(volatile U8* ) 0x000197)  // Group 3 waveform generate control register 7
#define G3BT     (*(volatile U16*) 0x0001A0)  // Group 3 base timer register
#define G3BCR0   (*(volatile U8* ) 0x0001A2)  // Group 3 base timer control register 0
#define G3BCR1   (*(volatile U8* ) 0x0001A3)  // Group 3 base timer control register 1
#define G3MR     (*(volatile U8* ) 0x00017A)  // Group 3 SI/O communication mode register
#define G3CR     (*(volatile U8* ) 0x00017B)  // Group 3 SI/O communication control register
#define G3TB     (*(volatile U16*) 0x00017C)  // Group 3 SI/O transmit buffer register
#define G3RB     (*(volatile U16*) 0x00017E)  // Group 3 SI/O receive buffer register
#define G3MK4    (*(volatile U16*) 0x000198)  // Group 3 WG mask register 4
#define G3MK5    (*(volatile U16*) 0x00019A)  // Group 3 WG mask register 5
#define G3MK6    (*(volatile U16*) 0x00019C)  // Group 3 WG mask register 6
#define G3MK7    (*(volatile U16*) 0x00019E)  // Group 3 WG mask register 7
#define G3FE     (*(volatile U8* ) 0x0001A6)  // Group 3 function enable register
#define G3RTP    (*(volatile U8* ) 0x0001A7)  // Group 3 RTP output buffer register
#define HDLC1    (*(volatile U8* ) 0x0001AB)  // Group 3 high-speed HDLC communication control register 1
#define HDLC     (*(volatile U8* ) 0x0001AC)  // Group 3 high-speed HDLC communication control register
#define HDLCF    (*(volatile U8* ) 0x0001AD)  // Group 3 high-speed HDLC communication register
#define HDLCC    (*(volatile U16*) 0x0001AE)  // Group 3 high-speed HDLC transmit counter
#define HDLCCP0  (*(volatile U16*) 0x0001B0)  // Group 3 high-speed HDLC data compare register 0
#define HDLCMK0  (*(volatile U16*) 0x0001B2)  // Group 3 high-speed HDLC data mask register 0
#define HDLCCP1  (*(volatile U16*) 0x0001B4)  // Group 3 high-speed HDLC data compare register 1
#define HDLCMK1  (*(volatile U16*) 0x0001B6)  // Group 3 high-speed HDLC data mask register 1
#define HDLCCP2  (*(volatile U16*) 0x0001B8)  // Group 3 high-speed HDLC data compare register 1
#define HDLCMK2  (*(volatile U16*) 0x0001BA)  // Group 3 high-speed HDLC data mask register 1
#define HDLCCP3  (*(volatile U16*) 0x0001BC)  // Group 3 high-speed HDLC data compare register 1
#define HDLCMK3  (*(volatile U16*) 0x0001BE)  // Group 3 high-speed HDLC data mask register 1

/************************  A-D Converter  *********************************/
#define AD00     (*(volatile U16*) 0x000380)  // A-D0 register 0
#define AD01     (*(volatile U16*) 0x000382)  // A-D0 register 1
#define AD02     (*(volatile U16*) 0x000384)  // A-D0 register 2
#define AD03     (*(volatile U16*) 0x000386)  // A-D0 register 3
#define AD04     (*(volatile U16*) 0x000388)  // A-D0 register 4
#define AD05     (*(volatile U16*) 0x00038A)  // A-D0 register 5
#define AD06     (*(volatile U16*) 0x00038C)  // A-D0 register 6
#define AD07     (*(volatile U16*) 0x00038E)  // A-D0 register 7
#define AD0CON0  (*(volatile U8* ) 0x000396)  // A-D0 control register 0
#define AD0CON1  (*(volatile U8* ) 0x000397)  // A-D0 control register 1
#define AD0CON2  (*(volatile U8* ) 0x000394)  // A-D0 control register 2

#define AD10     (*(volatile U16*) 0x0001C0)  // A-D1 register 0
#define AD11     (*(volatile U16*) 0x0001C2)  // A-D1 register 1
#define AD12     (*(volatile U16*) 0x0001C4)  // A-D1 register 2
#define AD13     (*(volatile U16*) 0x0001C6)  // A-D1 register 3
#define AD14     (*(volatile U16*) 0x0001C8)  // A-D1 register 4
#define AD15     (*(volatile U16*) 0x0001CA)  // A-D1 register 5
#define AD16     (*(volatile U16*) 0x0001CC)  // A-D1 register 6
#define AD17     (*(volatile U16*) 0x0001CE)  // A-D1 register 7
#define AD1CON0  (*(volatile U8* ) 0x0001D6)  // A-D1 control register 0
#define AD1CON1  (*(volatile U8* ) 0x0001D7)  // A-D1 control register 1
#define AD1CON2  (*(volatile U8* ) 0x0001D4)  // A-D1 control register 2

/************************  D-A Converter  *********************************/
#define DA0      (*(volatile U8* ) 0x000398)  // D-A register 0
#define DA1      (*(volatile U8* ) 0x00039A)  // D-A register 1
#define DACON    (*(volatile U8* ) 0x00039C)  // D-A control register

/************************  CAN0 register **********************************/
#define C0SLOT0_0  (*(volatile U8* ) 0x0001E0)  // CAN0 message slot buffer 0 standard ID0
#define C0SLOT0_1  (*(volatile U8* ) 0x0001E1)  // CAN0 message slot buffer 0 standard ID1
#define C0SLOT0_2  (*(volatile U8* ) 0x0001E2)  // CAN0 message slot buffer 0 extend ID0
#define C0SLOT0_3  (*(volatile U8* ) 0x0001E3)  // CAN0 message slot buffer 0 extend ID1
#define C0SLOT0_4  (*(volatile U8* ) 0x0001E4)  // CAN0 message slot buffer 0 extend ID2
#define C0SLOT0_5  (*(volatile U8* ) 0x0001E5)  // CAN0 message slot buffer 0 data length code
#define C0SLOT0_6  (*(volatile U8* ) 0x0001E6)  // CAN0 message slot buffer 0 data 0
#define C0SLOT0_7  (*(volatile U8* ) 0x0001E7)  // CAN0 message slot buffer 0 data 1
#define C0SLOT0_8  (*(volatile U8* ) 0x0001E8)  // CAN0 message slot buffer 0 data 2
#define C0SLOT0_9  (*(volatile U8* ) 0x0001E9)  // CAN0 message slot buffer 0 data 3
#define C0SLOT0_10 (*(volatile U8* ) 0x0001EA)  // CAN0 message slot buffer 0 data 4
#define C0SLOT0_11 (*(volatile U8* ) 0x0001EB)  // CAN0 message slot buffer 0 data 5
#define C0SLOT0_12 (*(volatile U8* ) 0x0001EC)  // CAN0 message slot buffer 0 data 6
#define C0SLOT0_13 (*(volatile U8* ) 0x0001ED)  // CAN0 message slot buffer 0 data 7
#define C0SLOT0_14 (*(volatile U8* ) 0x0001EE)  // CAN0 message slot buffer 0 time stamp high
#define C0SLOT0_15 (*(volatile U8* ) 0x0001EF)  // CAN0 message slot buffer 0 time stamp low
#define C0SLOT1_0  (*(volatile U8* ) 0x0001F0)  // CAN0 message slot buffer 1 standard ID0
#define C0SLOT1_1  (*(volatile U8* ) 0x0001F1)  // CAN0 message slot buffer 1 standard ID1
#define C0SLOT1_2  (*(volatile U8* ) 0x0001F2)  // CAN0 message slot buffer 1 extend ID0
#define C0SLOT1_3  (*(volatile U8* ) 0x0001F3)  // CAN0 message slot buffer 1 extend ID1
#define C0SLOT1_4  (*(volatile U8* ) 0x0001F4)  // CAN0 message slot buffer 1 extend ID2
#define C0SLOT1_5  (*(volatile U8* ) 0x0001F5)  // CAN0 message slot buffer 1 data length code
#define C0SLOT1_6  (*(volatile U8* ) 0x0001F6)  // CAN0 message slot buffer 1 data 0
#define C0SLOT1_7  (*(volatile U8* ) 0x0001F7)  // CAN0 message slot buffer 1 data 1
#define C0SLOT1_8  (*(volatile U8* ) 0x0001F8)  // CAN0 message slot buffer 1 data 2
#define C0SLOT1_9  (*(volatile U8* ) 0x0001F9)  // CAN0 message slot buffer 1 data 3
#define C0SLOT1_10 (*(volatile U8* ) 0x0001FA)  // CAN0 message slot buffer 1 data 4
#define C0SLOT1_11 (*(volatile U8* ) 0x0001FB)  // CAN0 message slot buffer 1 data 5
#define C0SLOT1_12 (*(volatile U8* ) 0x0001FC)  // CAN0 message slot buffer 1 data 6
#define C0SLOT1_13 (*(volatile U8* ) 0x0001FD)  // CAN0 message slot buffer 1 data 7
#define C0SLOT1_14 (*(volatile U8* ) 0x0001FE)  // CAN0 message slot buffer 1 time stamp high
#define C0SLOT1_15 (*(volatile U8* ) 0x0001FF)  // CAN0 message slot buffer 1 time stamp low
#define C0CTLR0    (*(volatile U16*) 0x000200)  // CAN0 control register 0
#define C0STR      (*(volatile U16*) 0x000202)  // CAN0 status register
#define C0IDR      (*(volatile U16*) 0x000204)  // CAN0 expansion ID register
#define C0CONR     (*(volatile U16*) 0x000206)  // CAN0 configuration register
#define C0TSR      (*(volatile U16*) 0x000208)  // CAN0 time stump register
#define C0TEC      (*(volatile U8* ) 0x00020A)  // CAN0 transmit error count register
#define C0REC      (*(volatile U8* ) 0x00020B)  // CAN0 receive error count register
#define C0SISTR    (*(volatile U16*) 0x00020C)  // CAN0 slot interrupt status register
#define C0SIMKR    (*(volatile U16*) 0x000210)  // CAN0 slot interrupt mask register
#define C0EIMKR    (*(volatile U8* ) 0x000213)  // CAN0 error interrupt mask register
#define C0EISTR    (*(volatile U8* ) 0x000214)  // CAN0 error interrupt status register
#define C0BPR      (*(volatile U8* ) 0x000217)  // CAN0 baud rate prescaler
#define C0GMR0     (*(volatile U8* ) 0x000228)  // CAN0 global mask register standard ID0
#define C0GMR1     (*(volatile U8* ) 0x000229)  // CAN0 global mask register standard ID1
#define C0GMR2     (*(volatile U8* ) 0x00022A)  // CAN0 global mask register extend ID0
#define C0GMR3     (*(volatile U8* ) 0x00022B)  // CAN0 global mask register extend ID1
#define C0GMR4     (*(volatile U8* ) 0x00022C)  // CAN0 global mask register extend ID2
#define COMCTL0    (*(volatile U8* ) 0x000230)  // CAN0 message slot 0 control register
#define COMCTL1    (*(volatile U8* ) 0x000231)  // CAN0 message slot 1 control register
#define COMCTL2    (*(volatile U8* ) 0x000232)  // CAN0 message slot 2 control register
#define COMCTL3    (*(volatile U8* ) 0x000233)  // CAN0 message slot 3 control register
#define COMCTL4    (*(volatile U8* ) 0x000234)  // CAN0 message slot 4 control register
#define COMCTL5    (*(volatile U8* ) 0x000235)  // CAN0 message slot 5 control register
#define COMCTL6    (*(volatile U8* ) 0x000236)  // CAN0 message slot 6 control register
#define COMCTL7    (*(volatile U8* ) 0x000237)  // CAN0 message slot 7 control register
#define COMCTL8    (*(volatile U8* ) 0x000238)  // CAN0 message slot 8 control register
#define COMCTL9    (*(volatile U8* ) 0x000239)  // CAN0 message slot 9 control register
#define COMCTL10   (*(volatile U8* ) 0x00023A)  // CAN0 message slot 10 control register
#define COMCTL11   (*(volatile U8* ) 0x00023B)  // CAN0 message slot 11 control register
#define COMCTL12   (*(volatile U8* ) 0x00023C)  // CAN0 message slot 12 control register
#define COMCTL13   (*(volatile U8* ) 0x00023D)  // CAN0 message slot 13 control register
#define COMCTL14   (*(volatile U8* ) 0x00023E)  // CAN0 message slot 14 control register
#define COMCTL15   (*(volatile U8* ) 0x00023F)  // CAN0 message slot 15 control register
#define COMLAR0    (*(volatile U8* ) 0x000230)  // CAN0 local mask register A standard ID0
#define COMLAR1    (*(volatile U8* ) 0x000231)  // CAN0 local mask register A standard ID1
#define COMLAR2    (*(volatile U8* ) 0x000232)  // CAN0 local mask register A extend ID0
#define COMLAR3    (*(volatile U8* ) 0x000233)  // CAN0 local mask register A extend ID1
#define COMLAR4    (*(volatile U8* ) 0x000234)  // CAN0 local mask register A extend ID2
#define COLMBR0    (*(volatile U8* ) 0x000238)  // CAN0 local mask register B standard ID0
#define COLMBR1    (*(volatile U8* ) 0x000239)  // CAN0 local mask register B standard ID1
#define COMLBR2    (*(volatile U8* ) 0x00023A)  // CAN0 local mask register B extend ID0
#define COMLBR3    (*(volatile U8* ) 0x00023B)  // CAN0 local mask register B extend ID1
#define COMLBR4    (*(volatile U8* ) 0x00023C)  // CAN0 local mask register B extend ID2
#define COSBS      (*(volatile U8* ) 0x000240)  // CAN0 slot buffer select register
#define COCTLR1    (*(volatile U8* ) 0x000241)  // CAN0 control register 1
#define COSLPR     (*(volatile U8* ) 0x000242)  // CAN0 sleep control register
#define C0AFS      (*(volatile U16*) 0x000244)  // CAN0 acceptance filter support register

/************************  X-Y Control Register  **************************/
#define X0R        (*(volatile U16*) 0x0002C0)  // X0 register
#define X1R        (*(volatile U16*) 0x0002C2)  // X1 register
#define X2R        (*(volatile U16*) 0x0002C4)  // X2 register
#define X3R        (*(volatile U16*) 0x0002C6)  // X3 register
#define X4R        (*(volatile U16*) 0x0002C8)  // X4 register
#define X5R        (*(volatile U16*) 0x0002CA)  // X5 register
#define X6R        (*(volatile U16*) 0x0002CC)  // X6 register
#define X7R        (*(volatile U16*) 0x0002CE)  // X7 register
#define X8R        (*(volatile U16*) 0x0002D0)  // X8 register
#define X9R        (*(volatile U16*) 0x0002D2)  // X9 register
#define X10R       (*(volatile U16*) 0x0002D4)  // X10 register
#define X11R       (*(volatile U16*) 0x0002D6)  // X11 register
#define X12R       (*(volatile U16*) 0x0002D8)  // X12 register
#define X13R       (*(volatile U16*) 0x0002DA)  // X13 register
#define X14R       (*(volatile U16*) 0x0002DC)  // X14 register
#define X15R       (*(volatile U16*) 0x0002DE)  // X15 register
#define Y0R        (*(volatile U16*) 0x0002C0)  // Y0 register
#define Y1R        (*(volatile U16*) 0x0002C2)  // Y1 register
#define Y2R        (*(volatile U16*) 0x0002C4)  // Y2 register
#define Y3R        (*(volatile U16*) 0x0002C6)  // Y3 register
#define Y4R        (*(volatile U16*) 0x0002C8)  // Y4 register
#define Y5R        (*(volatile U16*) 0x0002CA)  // Y5 register
#define Y6R        (*(volatile U16*) 0x0002CC)  // Y6 register
#define Y7R        (*(volatile U16*) 0x0002CE)  // Y7 register
#define Y8R        (*(volatile U16*) 0x0002D0)  // Y8 register
#define Y9R        (*(volatile U16*) 0x0002D2)  // Y9 register
#define Y10R       (*(volatile U16*) 0x0002D4)  // Y10 register
#define Y11R       (*(volatile U16*) 0x0002D6)  // Y11 register
#define Y12R       (*(volatile U16*) 0x0002D8)  // Y12 register
#define Y13R       (*(volatile U16*) 0x0002DA)  // Y13 register
#define Y14R       (*(volatile U16*) 0x0002DC)  // Y14 register
#define Y15R       (*(volatile U16*) 0x0002DE)  // Y15 register
#define XYC        (*(volatile U8* ) 0x0002E0)  // XY control register

/************************  UART Registers  ********************************/
#define U0SMR      (*(volatile U8* ) 0x000367)  // UART0 special mode register
#define U0SMR2     (*(volatile U8* ) 0x000366)  // UART0 special mode register 2
#define U0SMR3     (*(volatile U8* ) 0x000365)  // UART0 special mode register 3
#define U0SMR4     (*(volatile U8* ) 0x000364)  // UART0 special mode register 4
#define U0MR       (*(volatile U8* ) 0x000368)  // UART0 transmit-receive mode register
#define U0BRG      (*(volatile U8* ) 0x000369)  // UART0 bit rate generator
#define U0C0       (*(volatile U8* ) 0x00036C)  // UART0 transmit-receive control register 0
#define U0C1       (*(volatile U8* ) 0x00036D)  // UART0 transmit-receive control register 1
#define U0TB       (*(volatile U16*) 0x00036A)  // UART0 transmit buffer register
#define U0RB       (*(volatile U16*) 0x00036E)  // UART0 receive buffer register

#define U1SMR      (*(volatile U8* ) 0x0002E7)  // UART1 special mode register
#define U1SMR2     (*(volatile U8* ) 0x0002E6)  // UART1 special mode register 2
#define U1SMR3     (*(volatile U8* ) 0x0002E5)  // UART1 special mode register 3
#define U1SMR4     (*(volatile U8* ) 0x0002E4)  // UART1 special mode register 4
#define U1MR       (*(volatile U8* ) 0x0002E8)  // UART1 transmit-receive mode register
#define U1BRG      (*(volatile U8* ) 0x0002E9)  // UART1 bit rate generator
#define U1C0       (*(volatile U8* ) 0x0002EC)  // UART1 transmit-receive control register 0
#define U1C1       (*(volatile U8* ) 0x0002ED)  // UART1 transmit-receive control register 1
#define U1TB       (*(volatile U16*) 0x0002EA)  // UART1 transmit buffer register
#define U1RB       (*(volatile U16*) 0x0002EE)  // UART1 receive buffer register

#define U2SMR      (*(volatile U8* ) 0x000337)  // UART2 special mode register
#define U2SMR2     (*(volatile U8* ) 0x000336)  // UART2 special mode register 2
#define U2SMR3     (*(volatile U8* ) 0x000335)  // UART2 special mode register 3
#define U2SMR4     (*(volatile U8* ) 0x000334)  // UART2 special mode register 4
#define U2MR       (*(volatile U8* ) 0x000338)  // UART2 transmit-receive mode register
#define U2BRG      (*(volatile U8* ) 0x000339)  // UART2 bit rate generator
#define U2C0       (*(volatile U8* ) 0x00033C)  // UART2 transmit-receive control register 0
#define U2C1       (*(volatile U8* ) 0x00033D)  // UART2 transmit-receive control register 1
#define U2TB       (*(volatile U16*) 0x00033A)  // UART2 transmit buffer register
#define U2RB       (*(volatile U16*) 0x00033E)  // UART2 receive buffer register

#define U3SMR      (*(volatile U8* ) 0x000327)  // UART3 special mode register
#define U3SMR2     (*(volatile U8* ) 0x000326)  // UART3 special mode register 2
#define U3SMR3     (*(volatile U8* ) 0x000325)  // UART3 special mode register 3
#define U3SMR4     (*(volatile U8* ) 0x000324)  // UART3 special mode register 4
#define U3MR       (*(volatile U8* ) 0x000328)  // UART3 transmit-receive mode register
#define U3BRG      (*(volatile U8* ) 0x000329)  // UART3 bit rate generator
#define U3C0       (*(volatile U8* ) 0x00032C)  // UART3 transmit-receive control register 0
#define U3C1       (*(volatile U8* ) 0x00032D)  // UART3 transmit-receive control register 1
#define U3TB       (*(volatile U16*) 0x00032A)  // UART3 transmit buffer register
#define U3RB       (*(volatile U16*) 0x00032E)  // UART3 receive buffer register

#define U4SMR      (*(volatile U8* ) 0x0002F7)  // UART4 special mode register
#define U4SMR2     (*(volatile U8* ) 0x0002F6)  // UART4 special mode register 2
#define U4SMR3     (*(volatile U8* ) 0x0002F5)  // UART4 special mode register 3
#define U4SMR4     (*(volatile U8* ) 0x0002F4)  // UART4 special mode register 4
#define U4MR       (*(volatile U8* ) 0x0002F8)  // UART4 transmit-receive mode register
#define U4BRG      (*(volatile U8* ) 0x0002F9)  // UART4 bit rate generator
#define U4C0       (*(volatile U8* ) 0x0002FC)  // UART4 transmit-receive control register 0
#define U4C1       (*(volatile U8* ) 0x0002FD)  // UART4 transmit-receive control register 1
#define U4TB       (*(volatile U16*) 0x0002FA)  // UART4 transmit buffer register
#define U4RB       (*(volatile U16*) 0x0002FE)  // UART4 receive buffer register

/************************  Timer Registers  *******************************/
#define BTSR       (*(volatile U8* ) 0x000164)  // Base timer start register
#define UBSR       (*(volatile U8* ) 0x000300)  // Timer B3,B4,B5 count start flag
#define DTT        (*(volatile U8* ) 0x00030C)  // Dead time timer
#define ICTB2      (*(volatile U8* ) 0x00030D)  // Timer B2 interrupt occurence frequency set counter
#define TABSR      (*(volatile U8* ) 0x000340)  // Count start flag
#define CPSRF      (*(volatile U8* ) 0x000341)  // Clock prescaler reset flag
#define ONSF       (*(volatile U8* ) 0x000342)  // One-shot start flag
#define TRGSR      (*(volatile U8* ) 0x000343)  // Trigger select register
#define UDF        (*(volatile U8* ) 0x000344)  // Up-down flag
#define TCSPR      (*(volatile U8* ) 0x00035F)  // Count source prescaler register
#define INVC0      (*(volatile U8* ) 0x000308)  // Three-phase PWM control register 0
#define INVC1      (*(volatile U8* ) 0x000309)  // Three-phase PWM control register 1
#define IDB0       (*(volatile U8* ) 0x00030A)  // Three-phase output buffer register 0
#define IDB1       (*(volatile U8* ) 0x00030B)  // Three-phase output buffer register 1

#define TA0        (*(volatile U16*) 0x000346)  // Timer A0 register
#define TA0L       (*(volatile U8* ) 0x000346)  // Timer A0 register (low byte)
#define TA0H       (*(volatile U8* ) 0x000347)  // Timer A0 register (hight byte)
#define TA1        (*(volatile U16*) 0x000348)  // Timer A1 register
#define TA1L       (*(volatile U8* ) 0x000348)  // Timer A1 register (low byte)
#define TA1H       (*(volatile U8* ) 0x000349)  // Timer A1 register (hight byte)
#define TA11       (*(volatile U16*) 0x000302)  // Timer A1-1 register
#define TA11L      (*(volatile U8* ) 0x000302)  // Timer A1-1 register (low byte)
#define TA11H      (*(volatile U8* ) 0x000303)  // Timer A1-1 register (hight byte)
#define TA2        (*(volatile U16*) 0x00034A)  // Timer A2 register
#define TA2L       (*(volatile U8* ) 0x00034A)  // Timer A2 register (low byte)
#define TA2H       (*(volatile U8* ) 0x00034B)  // Timer A2 register (hight byte)
#define TA21       (*(volatile U16*) 0x000304)  // Timer A2-1 register
#define TA21L      (*(volatile U8* ) 0x000304)  // Timer A2-1 register (low byte)
#define TA21H      (*(volatile U8* ) 0x000305)  // Timer A2-1 register (hight byte)
#define TA3        (*(volatile U16*) 0x00034C)  // Timer A3 register
#define TA3L       (*(volatile U8* ) 0x00034C)  // Timer A3 register (low byte)
#define TA3H       (*(volatile U8* ) 0x00034D)  // Timer A3 register (hight byte)
#define TA4        (*(volatile U16*) 0x00034E)  // Timer A4 register
#define TA4L       (*(volatile U8* ) 0x00034E)  // Timer A4 register (low byte)
#define TA4H       (*(volatile U8* ) 0x00034F)  // Timer A4 register (hight byte)
#define TA41       (*(volatile U16*) 0x000306)  // Timer A4-1 register
#define TA41L      (*(volatile U8* ) 0x000306)  // Timer A4-1 register (low byte)
#define TA41H      (*(volatile U8* ) 0x000307)  // Timer A4-1 register (hight byte)
#define TB0        (*(volatile U16*) 0x000350)  // Timer B0 register
#define TB0L       (*(volatile U8* ) 0x000350)  // Timer B0 register (low byte)
#define TB0H       (*(volatile U8* ) 0x000351)  // Timer B0 register (hight byte)
#define TB1        (*(volatile U16*) 0x000352)  // Timer B1 register
#define TB1L       (*(volatile U8* ) 0x000352)  // Timer B1 register (low byte)
#define TB1H       (*(volatile U8* ) 0x000353)  // Timer B1 register (hight byte)
#define TB2        (*(volatile U16*) 0x000354)  // Timer B2 register
#define TB2L       (*(volatile U8* ) 0x000354)  // Timer B2 register (low byte)
#define TB2H       (*(volatile U8* ) 0x000355)  // Timer B2 register (hight byte)
#define TB3        (*(volatile U16*) 0x000310)  // Timer B3 register
#define TB3L       (*(volatile U8* ) 0x000310)  // Timer B3 register (low byte)
#define TB3H       (*(volatile U8* ) 0x000311)  // Timer B3 register (hight byte)
#define TB4        (*(volatile U16*) 0x000312)  // Timer B4 register
#define TB4L       (*(volatile U8* ) 0x000312)  // Timer B4 register (low byte)
#define TB4H       (*(volatile U8* ) 0x000313)  // Timer B4 register (hight byte)
#define TB5        (*(volatile U16*) 0x000314)  // Timer B5 register
#define TB5L       (*(volatile U8* ) 0x000314)  // Timer B5 register (low byte)
#define TB5H       (*(volatile U8* ) 0x000315)  // Timer B5 register (hight byte)

#define TA0MR      (*(volatile U8* ) 0x000356)  // Timer A0 mode register
#define TA1MR      (*(volatile U8* ) 0x000357)  // Timer A1 mode register
#define TA2MR      (*(volatile U8* ) 0x000358)  // Timer A2 mode register
#define TA3MR      (*(volatile U8* ) 0x000359)  // Timer A3 mode register
#define TA4MR      (*(volatile U8* ) 0x00035A)  // Timer A4 mode register
#define TB0MR      (*(volatile U8* ) 0x00035B)  // Timer B0 mode register
#define TB1MR      (*(volatile U8* ) 0x00035C)  // Timer B1 mode register
#define TB2MR      (*(volatile U8* ) 0x00035D)  // Timer B2 mode register
#define TB2SC      (*(volatile U8* ) 0x00035E)  // Timer B2 special mode register
#define TB3MR      (*(volatile U8* ) 0x00031B)  // Timer B3 mode register
#define TB4MR      (*(volatile U8* ) 0x00031C)  // Timer B4 mode register
#define TB5MR      (*(volatile U8* ) 0x00031D)  // Timer B5 mode register

/************************  DMA Registers  *********************************/
#define DM0SL      (*(volatile U8* ) 0x000378)  // DMA0 cause select register
#define DM1SL      (*(volatile U8* ) 0x000379)  // DMA1 cause select register
#define DM2SL      (*(volatile U8* ) 0x00037A)  // DMA2 cause select register
#define DM3SL      (*(volatile U8* ) 0x00037B)  // DMA3 cause select register

/************************  CRC register  **********************************/
#define CRCD       (*(volatile U16*) 0x00037C)  // CRC data register
#define CRCIN      (*(volatile U8* ) 0x00037E)  // CRC input register

/************************  Port Registers  ********************************/
#define PS0        (*(volatile U8* ) 0x0003B0)  // Function select register A0
#define PS1        (*(volatile U8* ) 0x0003B1)  // Function select register A1
#define PS2        (*(volatile U8* ) 0x0003B4)  // Function select register A2
#define PS3        (*(volatile U8* ) 0x0003B5)  // Function select register A3
#define PS5        (*(volatile U8* ) 0x0003B9)  // Function select register A5
#define PS6        (*(volatile U8* ) 0x0003BC)  // Function select register A6
#define PS7        (*(volatile U8* ) 0x0003BD)  // Function select register A7
#define PS8        (*(volatile U8* ) 0x0003A0)  // Function select register A8
#define PS9        (*(volatile U8* ) 0x0003A1)  // Function select register A9
#define PSL0       (*(volatile U8* ) 0x0003B2)  // Function select register B0
#define PSL1       (*(volatile U8* ) 0x0003B3)  // Function select register B1
#define PSL2       (*(volatile U8* ) 0x0003B6)  // Function select register B2
#define PSL3       (*(volatile U8* ) 0x0003B7)  // Function select register B3
#define PSC        (*(volatile U8* ) 0x0003AF)  // Function select register C

#define P0         (*(volatile U8* ) 0x0003E0)  // Port P0 register
#define PD0        (*(volatile U8* ) 0x0003E2)  // Port P0 direction register
#define P1         (*(volatile U8* ) 0x0003E1)  // Port P1 register
#define PD1        (*(volatile U8* ) 0x0003E3)  // Port P1 direction register
#define P2         (*(volatile U8* ) 0x0003E4)  // Port P2 register
#define PD2        (*(volatile U8* ) 0x0003E6)  // Port P2 direction register
#define P3         (*(volatile U8* ) 0x0003E5)  // Port P3 register
#define PD3        (*(volatile U8* ) 0x0003E7)  // Port P3 direction register
#define P4         (*(volatile U8* ) 0x0003E8)  // Port P4 register
#define PD4        (*(volatile U8* ) 0x0003EA)  // Port P4 direction register
#define P5         (*(volatile U8* ) 0x0003E9)  // Port P5 register
#define PD5        (*(volatile U8* ) 0x0003EB)  // Port P5 direction register
#define P6         (*(volatile U8* ) 0x0003C0)  // Port P6 register
#define PD6        (*(volatile U8* ) 0x0003C2)  // Port P6 direction register
#define P7         (*(volatile U8* ) 0x0003C1)  // Port P7 register
#define PD7        (*(volatile U8* ) 0x0003C3)  // Port P7 direction register
#define P8         (*(volatile U8* ) 0x0003C4)  // Port P8 register
#define PD8        (*(volatile U8* ) 0x0003C6)  // Port P8 direction register
#define P9         (*(volatile U8* ) 0x0003C5)  // Port P9 register
#define PD9        (*(volatile U8* ) 0x0003C7)  // Port P9 direction register
#define P10        (*(volatile U8* ) 0x0003C8)  // Port P10 register
#define PD10       (*(volatile U8* ) 0x0003CA)  // Port P10 direction register
#define P11        (*(volatile U8* ) 0x0003C9)  // Port P11 register
#define PD11       (*(volatile U8* ) 0x0003CB)  // Port P11 direction register
#define P12        (*(volatile U8* ) 0x0003CC)  // Port P12 register
#define PD12       (*(volatile U8* ) 0x0003CE)  // Port P12 direction register
#define P13        (*(volatile U8* ) 0x0003CD)  // Port P13 register
#define PD13       (*(volatile U8* ) 0x0003CF)  // Port P13 direction register
#define P14        (*(volatile U8* ) 0x0003D0)  // Port P14 register
#define PD14       (*(volatile U8* ) 0x0003D2)  // Port P14 direction register
#define P15        (*(volatile U8* ) 0x0003D1)  // Port P15 register
#define PD15       (*(volatile U8* ) 0x0003D3)  // Port P15 direction register

#define PUR0       (*(volatile U8* ) 0x0003F0)  // Pull-upp control register 0
#define PUR1       (*(volatile U8* ) 0x0003F1)  // Pull-upp control register 1
#define PUR2       (*(volatile U8* ) 0x0003DA)  // Pull-upp control register 2
#define PUR3       (*(volatile U8* ) 0x0003DB)  // Pull-upp control register 3
#define PUR4       (*(volatile U8* ) 0x0003DC)  // Pull-upp control register 4
#define PCR        (*(volatile U8* ) 0x0003FF)  // Port control register

