/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2013  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.88e                                            *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : CPUMC80.h
Purpose : SFR defines for M16C/80 CPU in ANSI C
---------------------------END-OF-HEADER------------------------------
*/

#define fct_loc_1

/****  data format definition  ***********************/   

#ifndef U8
  #define U8 unsigned char
#endif

#ifndef U16
  #define U16 unsigned short
#endif

#ifndef U32
  #define U32 unsigned long
#endif

/*****  Processor Registers  ***********************/

#define PM0     (*(volatile U8* ) 0x0004)  // Processor Mode Register 0
#define PM1     (*(volatile U8* ) 0x0005)  // Processor Mode Register 1
#define CM0     (*(volatile U8* ) 0x0006)  // System clock control register 0 
#define CM1     (*(volatile U8* ) 0x0007)  // System clock control register 1 
#define CM      (*(volatile U16*) 0x0006)  // System clock control register   
#define WCR     (*(volatile U8* ) 0x0008)  // Wait control register    
#define PRCR    (*(volatile U8* ) 0x000A)  // Protect register                         
#define DS      (*(volatile U8* ) 0x000B)  // External data bus width control
#define MCD     (*(volatile U8* ) 0x000C)  // Main clock division register
#define DRAMCON (*(volatile U8* ) 0x0040)  // DRAM control register
#define REFCNT  (*(volatile U8* ) 0x0041)  // DRAM refresh control register

/*****  Emulation Control Registers  ***************/
/*****  THESE REGISTERS ARE NOT AVAILABLE FOR USERS *******/

#define EIAD    (*(volatile U32*) 0x0020)  // Emulator interrupt vector table register
#define EIAD0   (*(volatile U8* ) 0x0020)  // Emulator interrupt vector table register (low)
#define EIAD1   (*(volatile U8* ) 0x0021)  // Emulator interrupt vector table register (mid)
#define EIAD2   (*(volatile U8* ) 0x0022)  // Emulator interrupt vector table register (high)
#define EITD    (*(volatile U8* ) 0x0023)  // Emulator interrupt detect register
#define EPRR    (*(volatile U8* ) 0x0024)  // Emulator protect register
#define ROA     (*(volatile U8* ) 0x0030)  // ROM area access control register
#define DBA     (*(volatile U8* ) 0x0031)  // Debug monitor area control register
#define EXA0    (*(volatile U8* ) 0x0032)  // Expansion area set register 0
#define EXA1    (*(volatile U8* ) 0x0033)  // Expansion area set register 1
#define EXA2    (*(volatile U8* ) 0x0034)  // Expansion area set register 2
#define EXA3    (*(volatile U8* ) 0x0035)  // Expansion area set register 3

/*****  Watchdog Timer  ********************************/

#define WDTS    (*(volatile U8* ) 0x000E)  // Watchdog timer start register   
#define WDC     (*(volatile U8* ) 0x000F)  // Watchdog timer control register 

/*****  Interrupt Control Register  ********************/

#define AIER    (*(volatile U8* ) 0x0009)  // Address match interrupt enable           
#define RMAD0   (*(volatile U32*) 0x0010)  // Address match interrupt register 0
#define RMAD00  (*(volatile U8* ) 0x0010)  // Address match interrupt register 0 (low) 
#define RMAD01  (*(volatile U8* ) 0x0011)  // Address match interrupt register 0 (mid) 
#define RMAD02  (*(volatile U8* ) 0x0012)  // Address match interrupt register 0 (high)
#define RMAD1   (*(volatile U32*) 0x0014)  // Address match interrupt register 1
#define RMAD10  (*(volatile U8* ) 0x0014)  // Address match interrupt register 1 (low) 
#define RMAD11  (*(volatile U8* ) 0x0015)  // Address match interrupt register 1 (mid) 
#define RMAD12  (*(volatile U8* ) 0x0016)  // Address match interrupt register 1 (high)
#define RMAD2   (*(volatile U32*) 0x0018)  // Address match interrupt register 2
#define RMAD20  (*(volatile U8* ) 0x0018)  // Address match interrupt register 2 (low) 
#define RMAD21  (*(volatile U8* ) 0x0019)  // Address match interrupt register 2 (mid) 
#define RMAD22  (*(volatile U8* ) 0x001A)  // Address match interrupt register 2 (high)
#define RMAD3   (*(volatile U32*) 0x001C)  // Address match interrupt register 3
#define RMAD30  (*(volatile U8* ) 0x001C)  // Address match interrupt register 3 (low) 
#define RMAD31  (*(volatile U8* ) 0x001D)  // Address match interrupt register 3 (mid) 
#define RMAD32  (*(volatile U8* ) 0x001E)  // Address match interrupt register 3 (high)
#define DMA0IC  (*(volatile U8* ) 0x004B)  // DMA0 interrupt control register          
#define DMA1IC  (*(volatile U8* ) 0x004C)  // DMA1 interrupt control register          
#define DMA2IC  (*(volatile U8* ) 0x006A)  // DMA2 interrupt control register          
#define DMA3IC  (*(volatile U8* ) 0x008A)  // DMA3 interrupt control register          
#define KUPIC   (*(volatile U8* ) 0x0093)  // Key input interrupt control register
#define ADIC    (*(volatile U8* ) 0x0073)  // A-D converter interrupt control register
#define S0TIC   (*(volatile U8* ) 0x0090)  // UART0 transmit interrupt control register
#define S0RIC   (*(volatile U8* ) 0x0072)  // UART0 receive interrupt control register 
#define S1TIC   (*(volatile U8* ) 0x0092)  // UART1 transmit interrupt control register
#define S1RIC   (*(volatile U8* ) 0x0074)  // UART1 receive interrupt control register 
#define S2TIC   (*(volatile U8* ) 0x0089)  // UART2 transmit interrupt control register
#define S2RIC   (*(volatile U8* ) 0x006B)  // UART2 receive interrupt control register 
#define BCN2IC  (*(volatile U8* ) 0x008F)  // UART2 bus collision interrupt control register 
#define S3TIC   (*(volatile U8* ) 0x008B)  // UART3 transmit interrupt control register
#define S3RIC   (*(volatile U8* ) 0x006D)  // UART3 receive interrupt control register 
#define BCN3IC  (*(volatile U8* ) 0x0071)  // UART3 bus collision interrupt control register 
#define S4TIC   (*(volatile U8* ) 0x008D)  // UART4 transmit interrupt control register
#define S4RIC   (*(volatile U8* ) 0x006F)  // UART4 receive interrupt control register 
#define BCN4IC  (*(volatile U8* ) 0x0091)  // UART4 bus collision interrupt control register 
#define TA0IC   (*(volatile U8* ) 0x006C)  // Timer A0 interrupt control register      
#define TA1IC   (*(volatile U8* ) 0x008C)  // Timer A1 interrupt control register      
#define TA2IC   (*(volatile U8* ) 0x006E)  // Timer A2 interrupt control register      
#define TA3IC   (*(volatile U8* ) 0x008E)  // Timer A3 interrupt control register      
#define TA4IC   (*(volatile U8* ) 0x0070)  // Timer A4 interrupt control register      
#define TB0IC   (*(volatile U8* ) 0x0094)  // Timer B0 interrupt control register      
#define TB1IC   (*(volatile U8* ) 0x0076)  // Timer B1 interrupt control register      
#define TB2IC   (*(volatile U8* ) 0x0096)  // Timer B2 interrupt control register      
#define TB3IC   (*(volatile U8* ) 0x0078)  // Timer B3 interrupt control register      
#define TB4IC   (*(volatile U8* ) 0x0098)  // Timer B4 interrupt control register      
#define TB5IC   (*(volatile U8* ) 0x0069)  // Timer B5 interrupt control register      
#define INT0IC  (*(volatile U8* ) 0x009E)  // Interrupt 0 interrupt control register   
#define INT1IC  (*(volatile U8* ) 0x007E)  // Interrupt 1 interrupt control register   
#define INT2IC  (*(volatile U8* ) 0x009C)  // Interrupt 2 interrupt control register   
#define INT3IC  (*(volatile U8* ) 0x007C)  // Interrupt 3 interrupt control register   
#define INT4IC  (*(volatile U8* ) 0x009A)  // Interrupt 4 interrupt control register   
#define INT5IC  (*(volatile U8* ) 0x007A)  // Interrupt 5 interrupt control register   
#define RLVL    (*(volatile U8* ) 0x009F)  // EXIT priority control register   

/*****  X-Y Control Register  **********************/

#define X0R     (*(volatile U16*) 0x02C0)  // X0 register
#define X1R     (*(volatile U16*) 0x02C2)  // X1 register
#define X2R     (*(volatile U16*) 0x02C4)  // X2 register
#define X3R     (*(volatile U16*) 0x02C6)  // X3 register
#define X4R     (*(volatile U16*) 0x02C8)  // X4 register
#define X5R     (*(volatile U16*) 0x02CA)  // X5 register
#define X6R     (*(volatile U16*) 0x02CC)  // X6 register
#define X7R     (*(volatile U16*) 0x02CE)  // X7 register
#define X8R     (*(volatile U16*) 0x02D0)  // X8 register
#define X9R     (*(volatile U16*) 0x02D2)  // X9 register
#define X10R    (*(volatile U16*) 0x02D4)  // X10 register
#define X11R    (*(volatile U16*) 0x02D6)  // X11 register
#define X12R    (*(volatile U16*) 0x02D8)  // X12 register
#define X13R    (*(volatile U16*) 0x02DA)  // X13 register
#define X14R    (*(volatile U16*) 0x02DC)  // X14 register
#define X15R    (*(volatile U16*) 0x02DE)  // X15 register
#define Y0R     (*(volatile U16*) 0x02C0)  // Y0 register
#define Y1R     (*(volatile U16*) 0x02C2)  // Y1 register
#define Y2R     (*(volatile U16*) 0x02C4)  // Y2 register
#define Y3R     (*(volatile U16*) 0x02C6)  // Y3 register
#define Y4R     (*(volatile U16*) 0x02C8)  // Y4 register
#define Y5R     (*(volatile U16*) 0x02CA)  // Y5 register
#define Y6R     (*(volatile U16*) 0x02CC)  // Y6 register
#define Y7R     (*(volatile U16*) 0x02CE)  // Y7 register
#define Y8R     (*(volatile U16*) 0x02D0)  // Y8 register
#define Y9R     (*(volatile U16*) 0x02D2)  // Y9 register
#define Y10R    (*(volatile U16*) 0x02D4)  // Y10 register
#define Y11R    (*(volatile U16*) 0x02D6)  // Y11 register
#define Y12R    (*(volatile U16*) 0x02D8)  // Y12 register
#define Y13R    (*(volatile U16*) 0x02DA)  // Y13 register
#define Y14R    (*(volatile U16*) 0x02DC)  // Y14 register
#define Y15R    (*(volatile U16*) 0x02DE)  // Y15 register
#define XYC     (*(volatile U16*) 0x02E0)  // XY control register

/*****  DMA Registers  *********************************/

#define DM0SL   (*(volatile U8* ) 0x0378)  // DMA0 cause selection  
#define DM1SL   (*(volatile U8* ) 0x037A)  // DMA1 cause selection  
#define DM2SL   (*(volatile U8* ) 0x037B)  // DMA2 cause selection  
#define DM3SL   (*(volatile U8* ) 0x037C)  // DMA3 cause selection  

/*****  Timer Registers  *******************************/

#define TABSR   (*(volatile U8* ) 0x0340)  // Timer A/B count start flags   
#define TBSR    (*(volatile U8* ) 0x0300)  // Timer B345 count start flags   
#define CPSRF   (*(volatile U8* ) 0x0341)  // Clock prescaler reset flag    
#define ONSF    (*(volatile U8* ) 0x0342)  // One-shot start flagl          
#define TRGSR   (*(volatile U8* ) 0x0343)  // Trigger select register       
#define UDF     (*(volatile U8* ) 0x0344)  // Up- down-count selection flag 
#define INVC0   (*(volatile U8* ) 0x0308)  // Inverter control register 0
#define INVC1   (*(volatile U8* ) 0x0309)  // Inverter control register 1
#define IDB0    (*(volatile U8* ) 0x030A)  // Inverter data buffer register 0
#define IDB1    (*(volatile U8* ) 0x030B)  // Inverter data buffer register 1
#define DTT     (*(volatile U8* ) 0x030C)  // Dead time timer
#define ICBT2   (*(volatile U8* ) 0x030D)  // Timer B2 interrupt ioccurence frequency set counter
                                  
#define TA0L    (*(volatile U8* ) 0x0346)  // Timer A0 (low byte)  
#define TA0H    (*(volatile U8* ) 0x0347)  // Timer A0 (high byte) 
#define TA0     (*(volatile U16*) 0x0346)  // Timer A0             
#define TA1L    (*(volatile U8* ) 0x0348)  // Timer A1 (low byte)  
#define TA1H    (*(volatile U8* ) 0x0349)  // Timer A1 (high byte) 
#define TA1     (*(volatile U16*) 0x0348)  // Timer A1             
#define TA11L   (*(volatile U8* ) 0x0302)  // Timer A11 (low byte)  
#define TA11H   (*(volatile U8* ) 0x0303)  // Timer A11 (high byte) 
#define TA11    (*(volatile U16*) 0x0302)  // Timer A11             
#define TA2L    (*(volatile U8* ) 0x034A)  // Timer A2 (low byte)  
#define TA2H    (*(volatile U8* ) 0x034B)  // Timer A2 (high byte) 
#define TA2     (*(volatile U16*) 0x034A)  // Timer A2             
#define TA21L   (*(volatile U8* ) 0x0304)  // Timer A21 (low byte)  
#define TA21H   (*(volatile U8* ) 0x0305)  // Timer A21 (high byte) 
#define TA21    (*(volatile U16*) 0x0304)  // Timer A21             
#define TA3L    (*(volatile U8* ) 0x034C)  // Timer A3 (low byte)  
#define TA3H    (*(volatile U8* ) 0x034D)  // Timer A3 (high byte) 
#define TA3     (*(volatile U16*) 0x034C)  // Timer A3             
#define TA4L    (*(volatile U8* ) 0x034E)  // Timer A4 (low byte)  
#define TA4H    (*(volatile U8* ) 0x034F)  // Timer A4 (high byte) 
#define TA4     (*(volatile U16*) 0x034E)  // Timer A4             
#define TA41L   (*(volatile U8* ) 0x0306)  // Timer A41 (low byte)  
#define TA41H   (*(volatile U8* ) 0x0307)  // Timer A41 (high byte) 
#define TA41    (*(volatile U16*) 0x0306)  // Timer A41             
#define TB0L    (*(volatile U8* ) 0x0350)  // Timer B0 (low byte)  
#define TB0H    (*(volatile U8* ) 0x0351)  // Timer B0 (high byte) 
#define TB0     (*(volatile U16*) 0x0350)  // Timer B0             
#define TB1L    (*(volatile U8* ) 0x0352)  // Timer B1 (low byte)  
#define TB1H    (*(volatile U8* ) 0x0353)  // Timer B1 (high byte) 
#define TB1     (*(volatile U16*) 0x0352)  // Timer B1             
#define TB2L    (*(volatile U8* ) 0x0354)  // Timer B2 (low byte)  
#define TB2H    (*(volatile U8* ) 0x0355)  // Timer B2 (high byte) 
#define TB2     (*(volatile U16*) 0x0354)  // Timer B2             
#define TB3L    (*(volatile U8* ) 0x0310)  // Timer B3 (low byte) */
#define TB3H    (*(volatile U8* ) 0x0311)  // Timer B3 (high byte) */
#define TB3     (*(volatile U16*) 0x0310)  // Timer B3 */
#define TB4L    (*(volatile U8* ) 0x0312)  // Timer B4 (low byte) */
#define TB4H    (*(volatile U8* ) 0x0313)  // Timer B4 (high byte) */
#define TB4     (*(volatile U16*) 0x0312)  // Timer B4 */
#define TB5L    (*(volatile U8* ) 0x0314)  // Timer B5 (low byte) */
#define TB5H    (*(volatile U8* ) 0x0315)  // Timer B5 (high byte) */
#define TB5     (*(volatile U16*) 0x0314)  // Timer B5 */
                                  
#define TA0MR   (*(volatile U8* ) 0x0356)  // Timer A0 mode register  
#define TA1MR   (*(volatile U8* ) 0x0357)  // Timer A1 mode register  
#define TA2MR   (*(volatile U8* ) 0x0358)  // Timer A2 mode register  
#define TA3MR   (*(volatile U8* ) 0x0359)  // Timer A3 mode register  
#define TA4MR   (*(volatile U8* ) 0x035A)  // Timer A4 mode register  
#define TB0MR   (*(volatile U8* ) 0x035B)  // Timer B0 mode register  
#define TB1MR   (*(volatile U8* ) 0x035C)  // Timer B1 mode register  
#define TB2MR   (*(volatile U8* ) 0x035D)  // Timer B2 mode register  
#define TB3MR   (*(volatile U8* ) 0x031B)  // Timer B3 mode register  
#define TB4MR   (*(volatile U8* ) 0x031C)  // Timer B4 mode register  
#define TB5MR   (*(volatile U8* ) 0x031D)  // Timer B5 mode register  

/*****  UART Registers  ********************************/

#define U0MR    (*(volatile U8* ) 0x0360)  // UART 0 mode register                
#define U0BRG   (*(volatile U8* ) 0x0361)  // UART 0 baud rate generator          
#define U0TBL   (*(volatile U8* ) 0x0362)  // UART 0 transmit buffer (low byte)   
#define U0TBH   (*(volatile U8* ) 0x0363)  // UART 0 transmit buffer (high byte)  
#define U0TB    (*(volatile U16*) 0x0362)  // UART 0 transmit buffer              
#define U0C0    (*(volatile U8* ) 0x0364)  // UART 0 control register 0           
#define U0C1    (*(volatile U8* ) 0x0365)  // UART 0 control register 1           
#define U0C     (*(volatile U16*) 0x0364)  // UART 0 control register             
#define U0RBL   (*(volatile U8* ) 0x0366)  // UART 0 receive buffer (low byte)    
#define U0RBH   (*(volatile U8* ) 0x0367)  // UART 0 receive buffer (high byte)   
#define U0RB    (*(volatile U16*) 0x0366)  // UART 0 receive buffer               
                                  
#define U1MR    (*(volatile U8* ) 0x0368)  // UART 1 mode register                
#define U1BRG   (*(volatile U8* ) 0x0369)  // UART 1 baud rate generator          
#define U1TBL   (*(volatile U8* ) 0x036A)  // UART 1 transmit buffer (low byte)   
#define U1TBH   (*(volatile U8* ) 0x036B)  // UART 1 transmit buffer (high byte)  
#define U1TB    (*(volatile U16*) 0x036A)  // UART 1 transmit buffer              
#define U1C0    (*(volatile U8* ) 0x036C)  // UART 1 control register 0           
#define U1C1    (*(volatile U8* ) 0x036D)  // UART 1 control register 1           
#define U1C     (*(volatile U16*) 0x036C)  // UART 1 control register             
#define U1RBL   (*(volatile U8* ) 0x036E)  // UART 1 receive buffer (low byte)    
#define U1RBH   (*(volatile U8* ) 0x036F)  // UART 1 receive buffer (high byte)   
#define U1RB    (*(volatile U16*) 0x036E)  // UART 1 receive buffer               

#define U2SMR2  (*(volatile U8* ) 0x0336)  // UART 2 special mode register 2
#define U2SMR   (*(volatile U8* ) 0x0337)  // UART 2 special mode register
#define U2MR    (*(volatile U8* ) 0x0338)  // UART 2 mode register
#define U2BRG   (*(volatile U8* ) 0x0339)  // UART 2 baud rate generator
#define U2TBL   (*(volatile U8* ) 0x033A)  // UART 2 transmit buffer (low byte)
#define U2TBH   (*(volatile U8* ) 0x033B)  // UART 2 transmit buffer (high byte)
#define U2TB    (*(volatile U16*) 0x033A)  // UART 2 transmit buffer
#define U2C0    (*(volatile U8* ) 0x033C)  // UART 2 control register 0
#define U2C1    (*(volatile U8* ) 0x033D)  // UART 2 control register 1
#define U2C     (*(volatile U16*) 0x033C)  // UART 2 control register
#define U2RBL   (*(volatile U8* ) 0x033E)  // UART 2 receive buffer (low byte)
#define U2RBH   (*(volatile U8* ) 0x033F)  // UART 2 receive buffer (high byte)
#define U2RB    (*(volatile U16*) 0x033E)  // UART 2 receive buffer

#define U3SMR2  (*(volatile U8* ) 0x0326)  // UART 3 special mode register 2
#define U3SMR   (*(volatile U8* ) 0x0327)  // UART 3 special mode register
#define U3MR    (*(volatile U8* ) 0x0328)  // UART 3 mode register
#define U3BRG   (*(volatile U8* ) 0x0329)  // UART 3 baud rate generator
#define U3TBL   (*(volatile U8* ) 0x032A)  // UART 3 transmit buffer (low byte)
#define U3TBH   (*(volatile U8* ) 0x032B)  // UART 3 transmit buffer (high byte)
#define U3TB    (*(volatile U16*) 0x032A)  // UART 3 transmit buffer
#define U3C0    (*(volatile U8* ) 0x032C)  // UART 3 control register 0
#define U3C1    (*(volatile U8* ) 0x032D)  // UART 3 control register 1
#define U3C     (*(volatile U16*) 0x032C)  // UART 3 control register
#define U3RBL   (*(volatile U8* ) 0x032E)  // UART 3 receive buffer (low byte)
#define U3RBH   (*(volatile U8* ) 0x032F)  // UART 3 receive buffer (high byte)
#define U3RB    (*(volatile U16*) 0x032E)  // UART 3 receive buffer

#define U4SMR2  (*(volatile U8* ) 0x02F6)  // UART 4 special mode register 2
#define U4SMR   (*(volatile U8* ) 0x02F7)  // UART 4 special mode register
#define U4MR    (*(volatile U8* ) 0x02F8)  // UART 4 mode register
#define U4BRG   (*(volatile U8* ) 0x02F9)  // UART 4 baud rate generator
#define U4TBL   (*(volatile U8* ) 0x02FA)  // UART 4 transmit buffer (low byte)
#define U4TBH   (*(volatile U8* ) 0x02FB)  // UART 4 transmit buffer (high byte)
#define U4TB    (*(volatile U16*) 0x02FA)  // UART 4 transmit buffer
#define U4C0    (*(volatile U8* ) 0x02FC)  // UART 4 control register 0
#define U4C1    (*(volatile U8* ) 0x02FD)  // UART 4 control register 1
#define U4C     (*(volatile U16*) 0x02FC)  // UART 4 control register
#define U4RBL   (*(volatile U8* ) 0x02FE)  // UART 4 receive buffer (low byte)
#define U4RBH   (*(volatile U8* ) 0x02FF)  // UART 4 receive buffer (high byte)
#define U4RB    (*(volatile U16*) 0x02FE)  // UART 4 receive buffer

#define UCON2   (*(volatile U8* ) 0x0370)  // UART control register 2             

/*****  CRC register  **********************************/

#define CRCDL   (*(volatile U8* ) 0x037C)  // CRC data register (low byte)  
#define CRCDH   (*(volatile U8* ) 0x037D)  // CRC data register (high byte) 
#define CRCD    (*(volatile U16*) 0x037C)  // CRC data register             
#define CRCIN   (*(volatile U8* ) 0x037E)  // CRC input register            

/*****  A/D Converter  *********************************/

#define AD0L    (*(volatile U8* ) 0x0380)  // A/D register 0 (low byte)   
#define AD0H    (*(volatile U8* ) 0x0381)  // A/D register 0 (high byte)  
#define AD0     (*(volatile U16*) 0x0380)  // A/D register 0              
#define AD1L    (*(volatile U8* ) 0x0382)  // A/D register 1 (low byte)   
#define AD1H    (*(volatile U8* ) 0x0383)  // A/D register 1 (high byte)  
#define AD1     (*(volatile U16*) 0x0382)  // A/D register 1              
#define AD2L    (*(volatile U8* ) 0x0384)  // A/D register 2 (low byte)   
#define AD2H    (*(volatile U8* ) 0x0385)  // A/D register 2 (high byte)  
#define AD2     (*(volatile U16*) 0x0384)  // A/D register 2              
#define AD3L    (*(volatile U8* ) 0x0386)  // A/D register 3 (low byte)   
#define AD3H    (*(volatile U8* ) 0x0387)  // A/D register 3 (high byte)  
#define AD3     (*(volatile U16*) 0x0386)  // A/D register 3              
#define AD4L    (*(volatile U8* ) 0x0388)  // A/D register 4 (low byte)   
#define AD4H    (*(volatile U8* ) 0x0389)  // A/D register 4 (high byte)  
#define AD4     (*(volatile U16*) 0x0388)  // A/D register 4              
#define AD5L    (*(volatile U8* ) 0x038A)  // A/D register 5 (low byte)   
#define AD5H    (*(volatile U8* ) 0x038B)  // A/D register 5 (high byte)  
#define AD5     (*(volatile U16*) 0x038A)  // A/D register 5              
#define AD6L    (*(volatile U8* ) 0x038C)  // A/D register 6 (low byte)   
#define AD6H    (*(volatile U8* ) 0x038D)  // A/D register 6 (high byte)  
#define AD6     (*(volatile U16*) 0x038C)  // A/D register 6              
#define AD7L    (*(volatile U8* ) 0x038E)  // A/D register 7 (low byte)   
#define AD7H    (*(volatile U8* ) 0x038F)  // A/D register 7 (high byte)  
#define AD7     (*(volatile U16*) 0x038E)  // A/D register 7              
                                  
#define ADCON2  (*(volatile U8* ) 0x0394)  // A/D control register 2
#define ADCON0  (*(volatile U8* ) 0x0396)  // A/D control register 0  
#define ADCON1  (*(volatile U8* ) 0x0397)  // A/D control register 1  
#define ADCON   (*(volatile U16*) 0x0396)  // A/D control register    

/*****  D-A Converter  *********************************/

#define DA0     (*(volatile U8* ) 0x0398)  // D-A register 0        
#define DA1     (*(volatile U8* ) 0x039A)  // D-A register 1        
#define DACON   (*(volatile U8* ) 0x039C)  // D-A control register  

/*****  Port Registers  ********************************/

#define PSC     (*(volatile U8* ) 0x03AF)  // Function select register C
#define PS0     (*(volatile U8* ) 0x03B0)  // Function select register 0
#define PS1     (*(volatile U8* ) 0x03B1)  // Function select register 1
#define PSL0    (*(volatile U8* ) 0x03B2)  // Function select register L0
#define PSL1    (*(volatile U8* ) 0x03B3)  // Function select register L1
#define PS2     (*(volatile U8* ) 0x03B4)  // Function select register 2
#define PS3     (*(volatile U8* ) 0x03B5)  // Function select register 3
#define PSL2    (*(volatile U8* ) 0x03B6)  // Function select register L2

#define P0      (*(volatile U8* ) 0x03E0)  // Port P0 register                   
#define P1      (*(volatile U8* ) 0x03E1)  // Port P1 register                   
#define P01     (*(volatile U16*) 0x03E0)  // Port P0 and P1 register            
#define PD0     (*(volatile U8* ) 0x03E2)  // Port P0 direction register         
#define PD1     (*(volatile U8* ) 0x03E3)  // Port P1 direction register         
#define PD01    (*(volatile U16*) 0x03E2)  // Port P0 and P1 direction register  
#define P2      (*(volatile U8* ) 0x03E4)  // Port P2 register                   
#define P3      (*(volatile U8* ) 0x03E5)  // Port P3 register                   
#define P23     (*(volatile U16*) 0x03E4)  // Port P2 and P3 register            
#define PD2     (*(volatile U8* ) 0x03E6)  // Port P2 direction register         
#define PD3     (*(volatile U8* ) 0x03E7)  // Port P3 direction register         
#define PD23    (*(volatile U16*) 0x03E6)  // Port P2 and P3 direction register  
#define P4      (*(volatile U8* ) 0x03E8)  // Port P4 register                   
#define P5      (*(volatile U8* ) 0x03E9)  // Port P5 register                   
#define P45     (*(volatile U16*) 0x03E8)  // Port P4 and P5 register            
#define PD4     (*(volatile U8* ) 0x03EA)  // Port P4 direction register         
#define PD5     (*(volatile U8* ) 0x03EB)  // Port P5 direction register         
#define PD45    (*(volatile U16*) 0x03EA)  // Port P4 and P5 direction register  
#define P6      (*(volatile U8* ) 0x03C0)  // Port P6 register                   
#define P7      (*(volatile U8* ) 0x03C1)  // Port P7 register                   
#define P67     (*(volatile U16*) 0x03C0)  // Port P6 and P7 register            
#define PD6     (*(volatile U8* ) 0x03C2)  // Port P6 direction register         
#define PD7     (*(volatile U8* ) 0x03C3)  // Port P7 direction register         
#define PD67    (*(volatile U16*) 0x03C2)  // Port P6 and P7 direction register  
#define P8      (*(volatile U8* ) 0x03C4)  // Port P8 register                   
#define P9      (*(volatile U8* ) 0x03C5)  // Port P9 register                   
#define P89     (*(volatile U16*) 0x03C4)  // Port P8 and P9 register            
#define PD8     (*(volatile U8* ) 0x03C6)  // Port P8 direction register         
#define PD9     (*(volatile U8* ) 0x03C7)  // Port P9 direction register         
#define PD89    (*(volatile U16*) 0x03C6)  // Port P8 and P9 direction register  
#define P10     (*(volatile U8* ) 0x03C8)  // Port P10 register                  
#define PD10    (*(volatile U8* ) 0x03CA)  // Port P10 direction register        
               
#define PUR0    (*(volatile U8* ) 0x03F0)  // Pull-up register 0                 
#define PUR1    (*(volatile U8* ) 0x03F1)  // Pull-up register 1                 
#define PUR01   (*(volatile U16*) 0x03F0)  // Pull-up register 01
#define PUR2    (*(volatile U8* ) 0x03DA)  // Pull-up register 2                 
#define PUR3    (*(volatile U8* ) 0x03DB)  // Pull-up register 2                 
#define PUR23   (*(volatile U16*) 0x03DA)  // Pull-up register 23

/****   EOF  ************************************************************/