;*******************************************************************************
;
;     C Compiler for M16C/80
;     Copyright 1999 MITSUBISHI ELECTRIC CORPORATION
;     AND MITSUBISHI ELECTRIC SEMICONDUCTOR APPLICATION ENGINEERING CORPORATION
;     All Rights Reserved.
;
;     Written by T.Aoyama
;
;     sect30.inc     : section definition
;     This program is applicable when using the basic I/O library
;
;     $Id: sect308.inc,v 1.6.2.2 2001/03/20 05:32:40 muramatu Exp $
;
;******************************************************************************



;******************************************************************************
;
;   Modifications required for use with embOS
;   by Segger Microcontroller Systeme GmbH
;
;   The original vector table definition file form Mitsubishi needs to be 
;   modified for use with embOS
;   The following modifications were made:
;
;   1.  external interrupt functions have to be declared
;       _OS_ISR_Tick    (the embOS timer interrupt function)
;       _OSTEST_X_ISR0  (only for internal test, may be removed)
;       _OS_ISR_tx      (Tx interrupt for embOSView)
;       _OS_ISR_rx      (Rx interrupt for embOSView)
;
;   2.  To calculate and check stack size, embOS needs information
;       about stack size and location
;       Therfore we export
;       _ISTACKSIZE     (.equ ISTACKSIZE)
;       _STACKSIZE      (.equ STACKSIZE)
;       stack_top       (last used stack address)
;       istack_top      (last used istack address)
;
;   3.  The interrupt vectors are inserted in the
;       variable vector section table
;       When using a different timer for embOS, please define
;       _OS_ISR_Tick as interrupt vector for your timer
;
;   4.  For use of KD308 (Renesas ROM monitor), two UART interrupt vectors
;       are defined for UART1
;       Therefore embOS can not use UART1 for communication in this case.
;       Default setting of UART for embOSView uses UART0 (see RTOSInit.c)
;   
;   5.  Heapsection removed to save RAM and ROM. Heap is not used with embOS
;       If dynamic memory allocation is required for your application, 
;       you may reenable heap section. Please note, that Heap management 
;       is not reentrant.
;
;   When using your own section definition file, please make sure,
;   that the above modifications are included
;
;****************************************************************************** 

;---------------------------------------------------------------------
; Externals for vector table used by embOS
;---------------------------------------------------------------------
.glb _OS_ISR_Tick
.glb _OSTEST_X_ISR0
.glb _OS_ISR_tx
.glb _OS_ISR_rx

;---------------------------------------------------------------------
; Externals for stack check functions used by embOS
;---------------------------------------------------------------------
.glb _STACKSIZE
.glb _ISTACKSIZE
.glb stack_top
.glb istack_top

_ISTACKSIZE .equ ISTACKSIZE
_STACKSIZE  .equ STACKSIZE

;---------------------------------------------------------------------


;---------------------------------------------------------------
;
;   Arrangement of section
;
;---------------------------------------------------------------
; Near RAM data area
;---------------------------------------------------------------
; SBDATA area
    .section    data_SE,DATA
    .org    400H
data_SE_top:

    .section    bss_SE,DATA,ALIGN
bss_SE_top:

    .section    data_SO,DATA
data_SO_top:

    .section    bss_SO,DATA
bss_SO_top:

; near RAM area
    .section    data_NE,DATA,ALIGN
data_NE_top:

    .section    bss_NE,DATA,ALIGN
bss_NE_top:

    .section    data_NO,DATA
data_NO_top:

    .section    bss_NO,DATA
bss_NO_top:

;---------------------------------------------------------------
; Stack area
;---------------------------------------------------------------
    .section    stack,DATA,ALIGN
    .blkb   STACKSIZE
    .align
stack_top:

    .blkb   ISTACKSIZE
    .align
istack_top:


;---------------------------------------------------------------
;   heap section
;---------------------------------------------------------------
;   Normally not used, commented out to save RAM and ROM
;   .section    heap,DATA
;heap_top:
;   .blkb   HEAPSIZE

;---------------------------------------------------------------
; Near ROM data area
;---------------------------------------------------------------
    .section    rom_NE,ROMDATA,ALIGN
rom_NE_top:

    .section    rom_NO,ROMDATA
rom_NO_top:

;---------------------------------------------------------------
; Far RAM data area
;---------------------------------------------------------------
    .section    data_FE,DATA
;   .org        10000H
data_FE_top:

    .section    bss_FE,DATA,ALIGN
bss_FE_top:
 
    .section    data_FO,DATA
data_FO_top:
 
    .section    bss_FO,DATA
bss_FO_top:


;---------------------------------------------------------------
; Far ROM data area
;---------------------------------------------------------------
    .section    rom_FE,ROMDATA
    .org        0FE0000H
rom_FE_top:

    .section    rom_FO,ROMDATA
rom_FO_top:

;---------------------------------------------------------------
; Initial data of 'data' section
;---------------------------------------------------------------
    .section    data_SEI,ROMDATA
data_SEI_top:

    .section    data_SOI,ROMDATA
data_SOI_top:

    .section    data_NEI,ROMDATA
data_NEI_top:
 
    .section    data_NOI,ROMDATA
data_NOI_top:
 
    .section    data_FEI,ROMDATA
data_FEI_top:
 
    .section    data_FOI,ROMDATA
data_FOI_top:

;---------------------------------------------------------------
; code area
;---------------------------------------------------------------
    .section    interrupt,ALIGN

    .section    program,ALIGN

    .section    program_S
    .org        0FF0000H

;---------------------------------------------------------------
; variable vector section
;---------------------------------------------------------------
    .section    vector      ; variable vector table
    .org    VECTOR_ADR 

    .lword  dummy_int       ; BRK (software int 0)
    .lword  dummy_int       ; 
    .lword  dummy_int       ; 
    .lword  dummy_int       ; 
    .lword  dummy_int       ; 
    .lword  dummy_int       ; 
    .lword  dummy_int       ; 
    .lword  dummy_int       ; 
    .lword  dummy_int       ; DMA0 (software int 8)
    .lword  dummy_int       ; DMA1 (software int 9)
    .lword  dummy_int       ; DMA2 (software int 10)
    .lword  dummy_int       ; DMA3 (software int 11)
;   .lword  dummy_int       ; TIMER A0 (software int 12)
    .lword  _OS_ISR_Tick    ; Timer A0 used for embOS

    .if OSTEST
    .lword  _OSTEST_X_ISR0  ; Timer A1 used for embOS test program only
    .else
    .lword  dummy_int       ; TIMER A1 (software int 13)
    .endif

    .lword  dummy_int       ; TIMER A2 (software int 14)
    .lword  dummy_int       ; TIMER A3 (software int 15)
    .lword  dummy_int       ; TIMER A4 (software int 16)
;   .lword  dummy_int       ; uart0 trance (software int 17)
;   .lword  dummy_int       ; uart0 receive (software int 18)

    .lword  _OS_ISR_tx      ; (Tx interrupt for embOSView, software int 17)
    .lword  _OS_ISR_rx      ; (Rx interrupt for embOSView, software int 18)

    ; *** When using KD308 or KD3083 with UART, the following interrupt vectors are required
;    .lword  0FFCB00h        ; KD308 transmit interrupt
;    .lword  0FFCB00h        ; KD308 receive interrupt

    .lword  0FFFD00h        ; KD3083 transmit interrupt for new M32C ROM-Monitor
    .lword  0FFFD00h        ; KD3083 receive interrupt

    ; *** embOS can not use UART 1 in this case
    ; *** To use UART1 for embOS, please comment out KD30 vectors
    ; *** end enable the following two vectors instead: 
         
;    .lword  _OS_ISR_tx      ; (Tx interrupt for embOSView, software int 19)
;    .lword  _OS_ISR_rx      ; (Rx interrupt for embOSView, software int 20)

    .lword  dummy_int       ; TIMER B0 (software int 21)
    .lword  dummy_int       ; TIMER B1 (software int 22)
    .lword  dummy_int       ; TIMER B2 (software int 23)
    .lword  dummy_int       ; TIMER B3 (software int 24)
    .lword  dummy_int       ; TIMER B4 (software int 25)
    .lword  dummy_int       ; INT5 (software int 26)
    .lword  dummy_int       ; INT4 (software int 27)
    .lword  dummy_int       ; INT3 (software int 28)
    .lword  dummy_int       ; INT2 (software int 29)
    .lword  dummy_int       ; INT1 (software int 30)
    .lword  dummy_int       ; INT0 (software int 31)
    .lword  dummy_int       ; TIMER B5 (software int 32)
    .lword  dummy_int       ; uart2 trance/NACK (software int 33)
    .lword  dummy_int       ; uart2 receive/ACK (software int 34)
    .lword  dummy_int       ; uart3 trance/NACK (software int 35)
    .lword  dummy_int       ; uart3 receive/ACK (software int 36)
    .lword  dummy_int       ; uart4 trance/NACK (software int 37)
    .lword  dummy_int       ; uart4 receive/ACK (software int 38)
    .lword  dummy_int       ; uart2 bus collision (software int 39)
    .lword  dummy_int       ; uart3 bus collision (software int 40)
    .lword  dummy_int       ; uart4 bus collision (software int 41)
    .lword  dummy_int       ; A-D Convert (software int 42)
    .lword  dummy_int       ; input key (software int 43)
    .lword  dummy_int       ; software int 44
    .lword  dummy_int       ; software int 45
    .lword  dummy_int       ; software int 46
    .lword  dummy_int       ; software int 47
    .lword  dummy_int       ; software int 48
    .lword  dummy_int       ; software int 49
    .lword  dummy_int       ; software int 50
    .lword  dummy_int       ; software int 51
    .lword  dummy_int       ; software int 52
    .lword  dummy_int       ; software int 53
    .lword  dummy_int       ; software int 54
    .lword  dummy_int       ; software int 55
    .lword  dummy_int       ; software int 56
    .lword  dummy_int       ; software int 57
    .lword  dummy_int       ; software int 58
    .lword  dummy_int       ; software int 59
    .lword  dummy_int       ; software int 60
    .lword  dummy_int       ; software int 61
    .lword  dummy_int       ; software int 62
    .lword  dummy_int       ; software int 63

;===============================================================
; fixed vector section
;---------------------------------------------------------------
    .section    fvector         ; fixed vector table
;===============================================================
; special page defination
;---------------------------------------------------------------
;   macro is defined in ncrt0.a30
;   Format: SPECIAL number
;
;---------------------------------------------------------------
;   SPECIAL 255
;   SPECIAL 254
;   SPECIAL 253
;      :
;      :
;   (omitted)
;      :
;      :
;   SPECIAL 24
;   SPECIAL 23
;   SPECIAL 22
;   SPECIAL 21
;   SPECIAL 20
;   SPECIAL 19
;   SPECIAL 18
;
;===============================================================
; fixed vector section
;---------------------------------------------------------------
    .org    0FFFFDCh
UDI:
    .lword  dummy_int
OVER_FLOW:
    .lword  dummy_int
BRKI:
    .lword  dummy_int
ADDRESS_MATCH:
    .lword  dummy_int
SINGLE_STEP:
    .lword  dummy_int
WDT:
    .lword  dummy_int
DBC:
    .lword  dummy_int
NMI:
    .lword  dummy_int
RESET:
    .lword  start
;
;*******************************************************************************
;
;     C Compiler for M16C/80
;     Copyright 1999 MITSUBISHI ELECTRIC CORPORATION
;     AND MITSUBISHI ELECTRIC SEMICONDUCTOR APPLICATION ENGINEERING CORPORATION
;     All Rights Reserved.
;
;*******************************************************************************

